# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiPatchRoleResponse(BaseModel):
    """
    PkiPatchRoleResponse
    """ # noqa: E501
    allow_any_name: Optional[StrictBool] = Field(default=None, description="If set, clients can request certificates for any domain, regardless of allowed_domains restrictions. See the documentation for more information.")
    allow_bare_domains: Optional[StrictBool] = Field(default=None, description="If set, clients can request certificates for the base domains themselves, e.g. \"example.com\" of domains listed in allowed_domains. This is a separate option as in some cases this can be considered a security threat. See the documentation for more information.")
    allow_glob_domains: Optional[StrictBool] = Field(default=None, description="If set, domains specified in allowed_domains can include shell-style glob patterns, e.g. \"ftp*.example.com\". See the documentation for more information.")
    allow_ip_sans: Optional[StrictBool] = Field(default=None, description="If set, IP Subject Alternative Names are allowed. Any valid IP is accepted and No authorization checking is performed.")
    allow_localhost: Optional[StrictBool] = Field(default=None, description="Whether to allow \"localhost\" and \"localdomain\" as a valid common name in a request, independent of allowed_domains value.")
    allow_subdomains: Optional[StrictBool] = Field(default=None, description="If set, clients can request certificates for subdomains of domains listed in allowed_domains, including wildcard subdomains. See the documentation for more information.")
    allow_token_displayname: Optional[StrictBool] = Field(default=None, description="Whether to allow \"localhost\" and \"localdomain\" as a valid common name in a request, independent of allowed_domains value.")
    allow_wildcard_certificates: Optional[StrictBool] = Field(default=None, description="If set, allows certificates with wildcards in the common name to be issued, conforming to RFC 6125's Section 6.4.3; e.g., \"*.example.net\" or \"b*z.example.net\". See the documentation for more information.")
    allowed_domains: Optional[List[StrictStr]] = Field(default=None, description="Specifies the domains this role is allowed to issue certificates for. This is used with the allow_bare_domains, allow_subdomains, and allow_glob_domains to determine matches for the common name, DNS-typed SAN entries, and Email-typed SAN entries of certificates. See the documentation for more information. This parameter accepts a comma-separated string or list of domains.")
    allowed_domains_template: Optional[StrictBool] = Field(default=None, description="If set, Allowed domains can be specified using identity template policies. Non-templated domains are also permitted.")
    allowed_other_sans: Optional[List[StrictStr]] = Field(default=None, description="If set, an array of allowed other names to put in SANs. These values support globbing and must be in the format <oid>;<type>:<value>. Currently only \"utf8\" is a valid type. All values, including globbing values, must use this syntax, with the exception being a single \"*\" which allows any OID and any value (but type must still be utf8).")
    allowed_serial_numbers: Optional[List[StrictStr]] = Field(default=None, description="If set, an array of allowed serial numbers to put in Subject. These values support globbing.")
    allowed_uri_sans: Optional[List[StrictStr]] = Field(default=None, description="If set, an array of allowed URIs for URI Subject Alternative Names. Any valid URI is accepted, these values support globbing.")
    allowed_uri_sans_template: Optional[StrictBool] = Field(default=None, description="If set, Allowed URI SANs can be specified using identity template policies. Non-templated URI SANs are also permitted.")
    allowed_user_ids: Optional[List[StrictStr]] = Field(default=None, description="If set, an array of allowed user-ids to put in user system login name specified here: https://www.rfc-editor.org/rfc/rfc1274#section-9.3.1")
    basic_constraints_valid_for_non_ca: Optional[StrictBool] = Field(default=None, description="Mark Basic Constraints valid when issuing non-CA certificates.")
    client_flag: Optional[StrictBool] = Field(default=None, description="If set, certificates are flagged for client auth use. Defaults to true. See also RFC 5280 Section 4.2.1.12.")
    cn_validations: Optional[List[StrictStr]] = Field(default=None, description="List of allowed validations to run against the Common Name field. Values can include 'email' to validate the CN is a email address, 'hostname' to validate the CN is a valid hostname (potentially including wildcards). When multiple validations are specified, these take OR semantics (either email OR hostname are allowed). The special value 'disabled' allows disabling all CN name validations, allowing for arbitrary non-Hostname, non-Email address CNs.")
    code_signing_flag: Optional[StrictBool] = Field(default=None, description="If set, certificates are flagged for code signing use. Defaults to false. See also RFC 5280 Section 4.2.1.12.")
    country: Optional[List[StrictStr]] = Field(default=None, description="If set, Country will be set to this value in certificates issued by this role.")
    email_protection_flag: Optional[StrictBool] = Field(default=None, description="If set, certificates are flagged for email protection use. Defaults to false. See also RFC 5280 Section 4.2.1.12.")
    enforce_hostnames: Optional[StrictBool] = Field(default=None, description="If set, only valid host names are allowed for CN and DNS SANs, and the host part of email addresses. Defaults to true.")
    ext_key_usage: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or list of extended key usages. Valid values can be found at https://golang.org/pkg/crypto/x509/#ExtKeyUsage -- simply drop the \"ExtKeyUsage\" part of the name. To remove all key usages from being set, set this value to an empty list. See also RFC 5280 Section 4.2.1.12.")
    ext_key_usage_oids: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or list of extended key usage oids.")
    generate_lease: Optional[StrictBool] = Field(default=None, description="If set, certificates issued/signed against this role will have Vault leases attached to them. Defaults to \"false\". Certificates can be added to the CRL by \"vault revoke <lease_id>\" when certificates are associated with leases. It can also be done using the \"pki/revoke\" endpoint. However, when lease generation is disabled, invoking \"pki/revoke\" would be the only way to add the certificates to the CRL. When large number of certificates are generated with long lifetimes, it is recommended that lease generation be disabled, as large amount of leases adversely affect the startup time of Vault.")
    issuer_ref: Optional[StrictStr] = Field(default=None, description="Reference to the issuer used to sign requests serviced by this role.")
    key_bits: Optional[StrictInt] = Field(default=None, description="The number of bits to use. Allowed values are 0 (universal default); with rsa key_type: 2048 (default), 3072, or 4096; with ec key_type: 224, 256 (default), 384, or 521; ignored with ed25519.")
    key_type: Optional[StrictStr] = Field(default=None, description="The type of key to use; defaults to RSA. \"rsa\" \"ec\", \"ed25519\" and \"any\" are the only valid values.")
    key_usage: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or list of key usages (not extended key usages). Valid values can be found at https://golang.org/pkg/crypto/x509/#KeyUsage -- simply drop the \"KeyUsage\" part of the name. To remove all key usages from being set, set this value to an empty list. See also RFC 5280 Section 4.2.1.3.")
    locality: Optional[List[StrictStr]] = Field(default=None, description="If set, Locality will be set to this value in certificates issued by this role.")
    max_ttl: Optional[StrictInt] = Field(default=None, description="The maximum allowed lease duration. If not set, defaults to the system maximum lease TTL.")
    no_store: Optional[StrictBool] = Field(default=None, description="If set, certificates issued/signed against this role will not be stored in the storage backend. This can improve performance when issuing large numbers of certificates. However, certificates issued in this way cannot be enumerated or revoked, so this option is recommended only for certificates that are non-sensitive, or extremely short-lived. This option implies a value of \"false\" for \"generate_lease\".")
    not_after: Optional[StrictStr] = Field(default=None, description="Set the not after field of the certificate with specified date value. The value format should be given in UTC format YYYY-MM-ddTHH:MM:SSZ.")
    not_before_duration: Optional[StrictInt] = Field(default=None, description="The duration in seconds before now which the certificate needs to be backdated by.")
    organization: Optional[List[StrictStr]] = Field(default=None, description="If set, O (Organization) will be set to this value in certificates issued by this role.")
    ou: Optional[List[StrictStr]] = Field(default=None, description="If set, OU (OrganizationalUnit) will be set to this value in certificates issued by this role.")
    policy_identifiers: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or list of policy OIDs, or a JSON list of qualified policy information, which must include an oid, and may include a notice and/or cps url, using the form [{\"oid\"=\"1.3.6.1.4.1.7.8\",\"notice\"=\"I am a user Notice\"}, {\"oid\"=\"1.3.6.1.4.1.44947.1.2.4 \",\"cps\"=\"https://example.com\"}].")
    postal_code: Optional[List[StrictStr]] = Field(default=None, description="If set, Postal Code will be set to this value in certificates issued by this role.")
    province: Optional[List[StrictStr]] = Field(default=None, description="If set, Province will be set to this value in certificates issued by this role.")
    require_cn: Optional[StrictBool] = Field(default=None, description="If set to false, makes the 'common_name' field optional while generating a certificate.")
    server_flag: Optional[StrictBool] = Field(default=True, description="If set, certificates are flagged for server auth use. Defaults to true. See also RFC 5280 Section 4.2.1.12.")
    signature_bits: Optional[StrictInt] = Field(default=None, description="The number of bits to use in the signature algorithm; accepts 256 for SHA-2-256, 384 for SHA-2-384, and 512 for SHA-2-512. Defaults to 0 to automatically detect based on key length (SHA-2-256 for RSA keys, and matching the curve size for NIST P-Curves).")
    street_address: Optional[List[StrictStr]] = Field(default=None, description="If set, Street Address will be set to this value in certificates issued by this role.")
    ttl: Optional[StrictInt] = Field(default=None, description="The lease duration (validity period of the certificate) if no specific lease duration is requested. The lease duration controls the expiration of certificates issued by this backend. Defaults to the system default value or the value of max_ttl, whichever is shorter.")
    use_csr_common_name: Optional[StrictBool] = Field(default=None, description="If set, when used with a signing profile, the common name in the CSR will be used. This does *not* include any requested Subject Alternative Names; use use_csr_sans for that. Defaults to true.")
    use_csr_sans: Optional[StrictBool] = Field(default=None, description="If set, when used with a signing profile, the SANs in the CSR will be used. This does *not* include the Common Name (cn); use use_csr_common_name for that. Defaults to true.")
    use_pss: Optional[StrictBool] = Field(default=None, description="Whether or not to use PSS signatures when using a RSA key-type issuer. Defaults to false.")
    __properties: ClassVar[List[str]] = ["allow_any_name", "allow_bare_domains", "allow_glob_domains", "allow_ip_sans", "allow_localhost", "allow_subdomains", "allow_token_displayname", "allow_wildcard_certificates", "allowed_domains", "allowed_domains_template", "allowed_other_sans", "allowed_serial_numbers", "allowed_uri_sans", "allowed_uri_sans_template", "allowed_user_ids", "basic_constraints_valid_for_non_ca", "client_flag", "cn_validations", "code_signing_flag", "country", "email_protection_flag", "enforce_hostnames", "ext_key_usage", "ext_key_usage_oids", "generate_lease", "issuer_ref", "key_bits", "key_type", "key_usage", "locality", "max_ttl", "no_store", "not_after", "not_before_duration", "organization", "ou", "policy_identifiers", "postal_code", "province", "require_cn", "server_flag", "signature_bits", "street_address", "ttl", "use_csr_common_name", "use_csr_sans", "use_pss"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiPatchRoleResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiPatchRoleResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_any_name": obj.get("allow_any_name"),
            "allow_bare_domains": obj.get("allow_bare_domains"),
            "allow_glob_domains": obj.get("allow_glob_domains"),
            "allow_ip_sans": obj.get("allow_ip_sans"),
            "allow_localhost": obj.get("allow_localhost"),
            "allow_subdomains": obj.get("allow_subdomains"),
            "allow_token_displayname": obj.get("allow_token_displayname"),
            "allow_wildcard_certificates": obj.get("allow_wildcard_certificates"),
            "allowed_domains": obj.get("allowed_domains"),
            "allowed_domains_template": obj.get("allowed_domains_template"),
            "allowed_other_sans": obj.get("allowed_other_sans"),
            "allowed_serial_numbers": obj.get("allowed_serial_numbers"),
            "allowed_uri_sans": obj.get("allowed_uri_sans"),
            "allowed_uri_sans_template": obj.get("allowed_uri_sans_template"),
            "allowed_user_ids": obj.get("allowed_user_ids"),
            "basic_constraints_valid_for_non_ca": obj.get("basic_constraints_valid_for_non_ca"),
            "client_flag": obj.get("client_flag"),
            "cn_validations": obj.get("cn_validations"),
            "code_signing_flag": obj.get("code_signing_flag"),
            "country": obj.get("country"),
            "email_protection_flag": obj.get("email_protection_flag"),
            "enforce_hostnames": obj.get("enforce_hostnames"),
            "ext_key_usage": obj.get("ext_key_usage"),
            "ext_key_usage_oids": obj.get("ext_key_usage_oids"),
            "generate_lease": obj.get("generate_lease"),
            "issuer_ref": obj.get("issuer_ref"),
            "key_bits": obj.get("key_bits"),
            "key_type": obj.get("key_type"),
            "key_usage": obj.get("key_usage"),
            "locality": obj.get("locality"),
            "max_ttl": obj.get("max_ttl"),
            "no_store": obj.get("no_store"),
            "not_after": obj.get("not_after"),
            "not_before_duration": obj.get("not_before_duration"),
            "organization": obj.get("organization"),
            "ou": obj.get("ou"),
            "policy_identifiers": obj.get("policy_identifiers"),
            "postal_code": obj.get("postal_code"),
            "province": obj.get("province"),
            "require_cn": obj.get("require_cn"),
            "server_flag": obj.get("server_flag") if obj.get("server_flag") is not None else True,
            "signature_bits": obj.get("signature_bits"),
            "street_address": obj.get("street_address"),
            "ttl": obj.get("ttl"),
            "use_csr_common_name": obj.get("use_csr_common_name"),
            "use_csr_sans": obj.get("use_csr_sans"),
            "use_pss": obj.get("use_pss")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.api.system_api import SystemApi


class TestSystemApi(unittest.TestCase):
    """SystemApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SystemApi()

    def tearDown(self) -> None:
        pass

    def test_auditing_calculate_hash(self) -> None:
        """Test case for auditing_calculate_hash

        """
        pass

    def test_auditing_disable_device(self) -> None:
        """Test case for auditing_disable_device

        Disable the audit device at the given path.
        """
        pass

    def test_auditing_disable_request_header(self) -> None:
        """Test case for auditing_disable_request_header

        Disable auditing of the given request header.
        """
        pass

    def test_auditing_enable_device(self) -> None:
        """Test case for auditing_enable_device

        Enable a new audit device at the supplied path.
        """
        pass

    def test_auditing_enable_request_header(self) -> None:
        """Test case for auditing_enable_request_header

        Enable auditing of a header.
        """
        pass

    def test_auditing_list_enabled_devices(self) -> None:
        """Test case for auditing_list_enabled_devices

        List the enabled audit devices.
        """
        pass

    def test_auditing_list_request_headers(self) -> None:
        """Test case for auditing_list_request_headers

        List the request headers that are configured to be audited.
        """
        pass

    def test_auditing_read_request_header_information(self) -> None:
        """Test case for auditing_read_request_header_information

        List the information for the given request header.
        """
        pass

    def test_auth_disable_method(self) -> None:
        """Test case for auth_disable_method

        Disable the auth method at the given auth path
        """
        pass

    def test_auth_enable_method(self) -> None:
        """Test case for auth_enable_method

        Enables a new auth method.
        """
        pass

    def test_auth_list_enabled_methods(self) -> None:
        """Test case for auth_list_enabled_methods

        """
        pass

    def test_auth_read_configuration(self) -> None:
        """Test case for auth_read_configuration

        Read the configuration of the auth engine at the given path.
        """
        pass

    def test_auth_read_tuning_information(self) -> None:
        """Test case for auth_read_tuning_information

        Reads the given auth path's configuration.
        """
        pass

    def test_auth_tune_configuration_parameters(self) -> None:
        """Test case for auth_tune_configuration_parameters

        Tune configuration parameters for a given auth path.
        """
        pass

    def test_collect_host_information(self) -> None:
        """Test case for collect_host_information

        Information about the host instance that this Vault server is running on.
        """
        pass

    def test_collect_in_flight_request_information(self) -> None:
        """Test case for collect_in_flight_request_information

        reports in-flight requests
        """
        pass

    def test_cors_configure(self) -> None:
        """Test case for cors_configure

        Configure the CORS settings.
        """
        pass

    def test_cors_delete_configuration(self) -> None:
        """Test case for cors_delete_configuration

        Remove any CORS settings.
        """
        pass

    def test_cors_read_configuration(self) -> None:
        """Test case for cors_read_configuration

        Return the current CORS settings.
        """
        pass

    def test_decode(self) -> None:
        """Test case for decode

        Decodes the encoded token with the otp.
        """
        pass

    def test_encryption_key_configure_rotation(self) -> None:
        """Test case for encryption_key_configure_rotation

        """
        pass

    def test_encryption_key_read_rotation_configuration(self) -> None:
        """Test case for encryption_key_read_rotation_configuration

        """
        pass

    def test_encryption_key_rotate(self) -> None:
        """Test case for encryption_key_rotate

        """
        pass

    def test_encryption_key_status(self) -> None:
        """Test case for encryption_key_status

        Provides information about the backend encryption key.
        """
        pass

    def test_enterprise_stub_delete_config_control_group(self) -> None:
        """Test case for enterprise_stub_delete_config_control_group

        """
        pass

    def test_enterprise_stub_delete_managed_keys_type_name(self) -> None:
        """Test case for enterprise_stub_delete_managed_keys_type_name

        """
        pass

    def test_enterprise_stub_delete_mfa_method_duo_name(self) -> None:
        """Test case for enterprise_stub_delete_mfa_method_duo_name

        """
        pass

    def test_enterprise_stub_delete_mfa_method_okta_name(self) -> None:
        """Test case for enterprise_stub_delete_mfa_method_okta_name

        """
        pass

    def test_enterprise_stub_delete_mfa_method_pingid_name(self) -> None:
        """Test case for enterprise_stub_delete_mfa_method_pingid_name

        """
        pass

    def test_enterprise_stub_delete_mfa_method_totp_name(self) -> None:
        """Test case for enterprise_stub_delete_mfa_method_totp_name

        """
        pass

    def test_enterprise_stub_delete_namespaces_path(self) -> None:
        """Test case for enterprise_stub_delete_namespaces_path

        """
        pass

    def test_enterprise_stub_delete_policies_egp_name(self) -> None:
        """Test case for enterprise_stub_delete_policies_egp_name

        """
        pass

    def test_enterprise_stub_delete_policies_rgp_name(self) -> None:
        """Test case for enterprise_stub_delete_policies_rgp_name

        """
        pass

    def test_enterprise_stub_delete_quotas_lease_count_name(self) -> None:
        """Test case for enterprise_stub_delete_quotas_lease_count_name

        """
        pass

    def test_enterprise_stub_delete_replication_performance_primary_paths_filter_id(self) -> None:
        """Test case for enterprise_stub_delete_replication_performance_primary_paths_filter_id

        """
        pass

    def test_enterprise_stub_delete_storage_raft_snapshot_auto_config_name(self) -> None:
        """Test case for enterprise_stub_delete_storage_raft_snapshot_auto_config_name

        """
        pass

    def test_enterprise_stub_list_managed_keys_type(self) -> None:
        """Test case for enterprise_stub_list_managed_keys_type

        """
        pass

    def test_enterprise_stub_list_mfa_method(self) -> None:
        """Test case for enterprise_stub_list_mfa_method

        """
        pass

    def test_enterprise_stub_list_namespaces(self) -> None:
        """Test case for enterprise_stub_list_namespaces

        """
        pass

    def test_enterprise_stub_list_policies_egp(self) -> None:
        """Test case for enterprise_stub_list_policies_egp

        """
        pass

    def test_enterprise_stub_list_policies_rgp(self) -> None:
        """Test case for enterprise_stub_list_policies_rgp

        """
        pass

    def test_enterprise_stub_list_quotas_lease_count(self) -> None:
        """Test case for enterprise_stub_list_quotas_lease_count

        """
        pass

    def test_enterprise_stub_list_storage_raft_snapshot_auto_config(self) -> None:
        """Test case for enterprise_stub_list_storage_raft_snapshot_auto_config

        """
        pass

    def test_enterprise_stub_read_config_control_group(self) -> None:
        """Test case for enterprise_stub_read_config_control_group

        """
        pass

    def test_enterprise_stub_read_config_group_policy_application(self) -> None:
        """Test case for enterprise_stub_read_config_group_policy_application

        """
        pass

    def test_enterprise_stub_read_license_status(self) -> None:
        """Test case for enterprise_stub_read_license_status

        """
        pass

    def test_enterprise_stub_read_managed_keys_type_name(self) -> None:
        """Test case for enterprise_stub_read_managed_keys_type_name

        """
        pass

    def test_enterprise_stub_read_mfa_method_duo_name(self) -> None:
        """Test case for enterprise_stub_read_mfa_method_duo_name

        """
        pass

    def test_enterprise_stub_read_mfa_method_okta_name(self) -> None:
        """Test case for enterprise_stub_read_mfa_method_okta_name

        """
        pass

    def test_enterprise_stub_read_mfa_method_pingid_name(self) -> None:
        """Test case for enterprise_stub_read_mfa_method_pingid_name

        """
        pass

    def test_enterprise_stub_read_mfa_method_totp_name(self) -> None:
        """Test case for enterprise_stub_read_mfa_method_totp_name

        """
        pass

    def test_enterprise_stub_read_mfa_method_totp_name_generate(self) -> None:
        """Test case for enterprise_stub_read_mfa_method_totp_name_generate

        """
        pass

    def test_enterprise_stub_read_namespaces_path(self) -> None:
        """Test case for enterprise_stub_read_namespaces_path

        """
        pass

    def test_enterprise_stub_read_plugins_reload_backend_status(self) -> None:
        """Test case for enterprise_stub_read_plugins_reload_backend_status

        """
        pass

    def test_enterprise_stub_read_policies_egp_name(self) -> None:
        """Test case for enterprise_stub_read_policies_egp_name

        """
        pass

    def test_enterprise_stub_read_policies_rgp_name(self) -> None:
        """Test case for enterprise_stub_read_policies_rgp_name

        """
        pass

    def test_enterprise_stub_read_quotas_lease_count_name(self) -> None:
        """Test case for enterprise_stub_read_quotas_lease_count_name

        """
        pass

    def test_enterprise_stub_read_replication_dr_secondary_license_status(self) -> None:
        """Test case for enterprise_stub_read_replication_dr_secondary_license_status

        """
        pass

    def test_enterprise_stub_read_replication_dr_status(self) -> None:
        """Test case for enterprise_stub_read_replication_dr_status

        """
        pass

    def test_enterprise_stub_read_replication_performance_primary_dynamic_filter_id(self) -> None:
        """Test case for enterprise_stub_read_replication_performance_primary_dynamic_filter_id

        """
        pass

    def test_enterprise_stub_read_replication_performance_primary_paths_filter_id(self) -> None:
        """Test case for enterprise_stub_read_replication_performance_primary_paths_filter_id

        """
        pass

    def test_enterprise_stub_read_replication_performance_secondary_dynamic_filter_id(self) -> None:
        """Test case for enterprise_stub_read_replication_performance_secondary_dynamic_filter_id

        """
        pass

    def test_enterprise_stub_read_replication_performance_status(self) -> None:
        """Test case for enterprise_stub_read_replication_performance_status

        """
        pass

    def test_enterprise_stub_read_sealwrap_rewrap(self) -> None:
        """Test case for enterprise_stub_read_sealwrap_rewrap

        """
        pass

    def test_enterprise_stub_read_storage_raft_snapshot_auto_config_name(self) -> None:
        """Test case for enterprise_stub_read_storage_raft_snapshot_auto_config_name

        """
        pass

    def test_enterprise_stub_read_storage_raft_snapshot_auto_status_name(self) -> None:
        """Test case for enterprise_stub_read_storage_raft_snapshot_auto_status_name

        """
        pass

    def test_enterprise_stub_write_config_control_group(self) -> None:
        """Test case for enterprise_stub_write_config_control_group

        """
        pass

    def test_enterprise_stub_write_config_group_policy_application(self) -> None:
        """Test case for enterprise_stub_write_config_group_policy_application

        """
        pass

    def test_enterprise_stub_write_control_group_authorize(self) -> None:
        """Test case for enterprise_stub_write_control_group_authorize

        """
        pass

    def test_enterprise_stub_write_control_group_request(self) -> None:
        """Test case for enterprise_stub_write_control_group_request

        """
        pass

    def test_enterprise_stub_write_managed_keys_type_name(self) -> None:
        """Test case for enterprise_stub_write_managed_keys_type_name

        """
        pass

    def test_enterprise_stub_write_managed_keys_type_name_test_sign(self) -> None:
        """Test case for enterprise_stub_write_managed_keys_type_name_test_sign

        """
        pass

    def test_enterprise_stub_write_mfa_method_duo_name(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_duo_name

        """
        pass

    def test_enterprise_stub_write_mfa_method_okta_name(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_okta_name

        """
        pass

    def test_enterprise_stub_write_mfa_method_pingid_name(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_pingid_name

        """
        pass

    def test_enterprise_stub_write_mfa_method_totp_name(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_totp_name

        """
        pass

    def test_enterprise_stub_write_mfa_method_totp_name_admin_destroy(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_totp_name_admin_destroy

        """
        pass

    def test_enterprise_stub_write_mfa_method_totp_name_admin_generate(self) -> None:
        """Test case for enterprise_stub_write_mfa_method_totp_name_admin_generate

        """
        pass

    def test_enterprise_stub_write_namespaces_api_lock_lock(self) -> None:
        """Test case for enterprise_stub_write_namespaces_api_lock_lock

        """
        pass

    def test_enterprise_stub_write_namespaces_api_lock_lock_path(self) -> None:
        """Test case for enterprise_stub_write_namespaces_api_lock_lock_path

        """
        pass

    def test_enterprise_stub_write_namespaces_api_lock_unlock(self) -> None:
        """Test case for enterprise_stub_write_namespaces_api_lock_unlock

        """
        pass

    def test_enterprise_stub_write_namespaces_api_lock_unlock_path(self) -> None:
        """Test case for enterprise_stub_write_namespaces_api_lock_unlock_path

        """
        pass

    def test_enterprise_stub_write_namespaces_path(self) -> None:
        """Test case for enterprise_stub_write_namespaces_path

        """
        pass

    def test_enterprise_stub_write_policies_egp_name(self) -> None:
        """Test case for enterprise_stub_write_policies_egp_name

        """
        pass

    def test_enterprise_stub_write_policies_rgp_name(self) -> None:
        """Test case for enterprise_stub_write_policies_rgp_name

        """
        pass

    def test_enterprise_stub_write_quotas_lease_count_name(self) -> None:
        """Test case for enterprise_stub_write_quotas_lease_count_name

        """
        pass

    def test_enterprise_stub_write_replication_dr_primary_demote(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_primary_demote

        """
        pass

    def test_enterprise_stub_write_replication_dr_primary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_primary_disable

        """
        pass

    def test_enterprise_stub_write_replication_dr_primary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_primary_enable

        """
        pass

    def test_enterprise_stub_write_replication_dr_primary_revoke_secondary(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_primary_revoke_secondary

        """
        pass

    def test_enterprise_stub_write_replication_dr_primary_secondary_token(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_primary_secondary_token

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_config_reload_subsystem(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_config_reload_subsystem

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_disable

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_enable

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_generate_public_key(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_generate_public_key

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_operation_token_delete(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_operation_token_delete

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_promote(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_promote

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_recover(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_recover

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_reindex(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_reindex

        """
        pass

    def test_enterprise_stub_write_replication_dr_secondary_update_primary(self) -> None:
        """Test case for enterprise_stub_write_replication_dr_secondary_update_primary

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_demote(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_demote

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_disable

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_enable

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_paths_filter_id(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_paths_filter_id

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_revoke_secondary(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_revoke_secondary

        """
        pass

    def test_enterprise_stub_write_replication_performance_primary_secondary_token(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_primary_secondary_token

        """
        pass

    def test_enterprise_stub_write_replication_performance_secondary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_secondary_disable

        """
        pass

    def test_enterprise_stub_write_replication_performance_secondary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_secondary_enable

        """
        pass

    def test_enterprise_stub_write_replication_performance_secondary_generate_public_key(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_secondary_generate_public_key

        """
        pass

    def test_enterprise_stub_write_replication_performance_secondary_promote(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_secondary_promote

        """
        pass

    def test_enterprise_stub_write_replication_performance_secondary_update_primary(self) -> None:
        """Test case for enterprise_stub_write_replication_performance_secondary_update_primary

        """
        pass

    def test_enterprise_stub_write_replication_primary_demote(self) -> None:
        """Test case for enterprise_stub_write_replication_primary_demote

        """
        pass

    def test_enterprise_stub_write_replication_primary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_primary_disable

        """
        pass

    def test_enterprise_stub_write_replication_primary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_primary_enable

        """
        pass

    def test_enterprise_stub_write_replication_primary_revoke_secondary(self) -> None:
        """Test case for enterprise_stub_write_replication_primary_revoke_secondary

        """
        pass

    def test_enterprise_stub_write_replication_primary_secondary_token(self) -> None:
        """Test case for enterprise_stub_write_replication_primary_secondary_token

        """
        pass

    def test_enterprise_stub_write_replication_recover(self) -> None:
        """Test case for enterprise_stub_write_replication_recover

        """
        pass

    def test_enterprise_stub_write_replication_reindex(self) -> None:
        """Test case for enterprise_stub_write_replication_reindex

        """
        pass

    def test_enterprise_stub_write_replication_secondary_disable(self) -> None:
        """Test case for enterprise_stub_write_replication_secondary_disable

        """
        pass

    def test_enterprise_stub_write_replication_secondary_enable(self) -> None:
        """Test case for enterprise_stub_write_replication_secondary_enable

        """
        pass

    def test_enterprise_stub_write_replication_secondary_promote(self) -> None:
        """Test case for enterprise_stub_write_replication_secondary_promote

        """
        pass

    def test_enterprise_stub_write_replication_secondary_update_primary(self) -> None:
        """Test case for enterprise_stub_write_replication_secondary_update_primary

        """
        pass

    def test_enterprise_stub_write_sealwrap_rewrap(self) -> None:
        """Test case for enterprise_stub_write_sealwrap_rewrap

        """
        pass

    def test_enterprise_stub_write_storage_raft_snapshot_auto_config_name(self) -> None:
        """Test case for enterprise_stub_write_storage_raft_snapshot_auto_config_name

        """
        pass

    def test_generate_hash(self) -> None:
        """Test case for generate_hash

        """
        pass

    def test_generate_hash_with_algorithm(self) -> None:
        """Test case for generate_hash_with_algorithm

        """
        pass

    def test_generate_random(self) -> None:
        """Test case for generate_random

        """
        pass

    def test_generate_random_with_bytes(self) -> None:
        """Test case for generate_random_with_bytes

        """
        pass

    def test_generate_random_with_source(self) -> None:
        """Test case for generate_random_with_source

        """
        pass

    def test_generate_random_with_source_and_bytes(self) -> None:
        """Test case for generate_random_with_source_and_bytes

        """
        pass

    def test_ha_status(self) -> None:
        """Test case for ha_status

        Check the HA status of a Vault cluster
        """
        pass

    def test_initialize(self) -> None:
        """Test case for initialize

        Initialize a new Vault.
        """
        pass

    def test_internal_client_activity_configure(self) -> None:
        """Test case for internal_client_activity_configure

        Enable or disable collection of client count, set retention period, or set default reporting period.
        """
        pass

    def test_internal_client_activity_export(self) -> None:
        """Test case for internal_client_activity_export

        Report the client count metrics, for this namespace and all child namespaces.
        """
        pass

    def test_internal_client_activity_read_configuration(self) -> None:
        """Test case for internal_client_activity_read_configuration

        Read the client count tracking configuration.
        """
        pass

    def test_internal_client_activity_report_counts(self) -> None:
        """Test case for internal_client_activity_report_counts

        Report the client count metrics, for this namespace and all child namespaces.
        """
        pass

    def test_internal_client_activity_report_counts_this_month(self) -> None:
        """Test case for internal_client_activity_report_counts_this_month

        Report the number of clients for this month, for this namespace and all child namespaces.
        """
        pass

    def test_internal_count_entities(self) -> None:
        """Test case for internal_count_entities

        Backwards compatibility is not guaranteed for this API
        """
        pass

    def test_internal_count_requests(self) -> None:
        """Test case for internal_count_requests

        Backwards compatibility is not guaranteed for this API
        """
        pass

    def test_internal_count_tokens(self) -> None:
        """Test case for internal_count_tokens

        Backwards compatibility is not guaranteed for this API
        """
        pass

    def test_internal_generate_open_api_document(self) -> None:
        """Test case for internal_generate_open_api_document

        """
        pass

    def test_internal_generate_open_api_document_with_parameters(self) -> None:
        """Test case for internal_generate_open_api_document_with_parameters

        """
        pass

    def test_internal_inspect_router(self) -> None:
        """Test case for internal_inspect_router

        Expose the route entry and mount entry tables present in the router
        """
        pass

    def test_internal_ui_list_enabled_feature_flags(self) -> None:
        """Test case for internal_ui_list_enabled_feature_flags

        Lists enabled feature flags.
        """
        pass

    def test_internal_ui_list_enabled_visible_mounts(self) -> None:
        """Test case for internal_ui_list_enabled_visible_mounts

        Lists all enabled and visible auth and secrets mounts.
        """
        pass

    def test_internal_ui_list_namespaces(self) -> None:
        """Test case for internal_ui_list_namespaces

        Backwards compatibility is not guaranteed for this API
        """
        pass

    def test_internal_ui_read_mount_information(self) -> None:
        """Test case for internal_ui_read_mount_information

        Return information about the given mount.
        """
        pass

    def test_internal_ui_read_resultant_acl(self) -> None:
        """Test case for internal_ui_read_resultant_acl

        Backwards compatibility is not guaranteed for this API
        """
        pass

    def test_leader_status(self) -> None:
        """Test case for leader_status

        Returns the high availability status and current leader instance of Vault.
        """
        pass

    def test_leases_count(self) -> None:
        """Test case for leases_count

        """
        pass

    def test_leases_force_revoke_lease_with_prefix(self) -> None:
        """Test case for leases_force_revoke_lease_with_prefix

        Revokes all secrets or tokens generated under a given prefix immediately
        """
        pass

    def test_leases_force_revoke_lease_with_prefix2(self) -> None:
        """Test case for leases_force_revoke_lease_with_prefix2

        Revokes all secrets or tokens generated under a given prefix immediately
        """
        pass

    def test_leases_list(self) -> None:
        """Test case for leases_list

        """
        pass

    def test_leases_look_up(self) -> None:
        """Test case for leases_look_up

        """
        pass

    def test_leases_read_lease(self) -> None:
        """Test case for leases_read_lease

        """
        pass

    def test_leases_renew_lease(self) -> None:
        """Test case for leases_renew_lease

        Renews a lease, requesting to extend the lease.
        """
        pass

    def test_leases_renew_lease2(self) -> None:
        """Test case for leases_renew_lease2

        Renews a lease, requesting to extend the lease.
        """
        pass

    def test_leases_renew_lease_with_id(self) -> None:
        """Test case for leases_renew_lease_with_id

        Renews a lease, requesting to extend the lease.
        """
        pass

    def test_leases_renew_lease_with_id2(self) -> None:
        """Test case for leases_renew_lease_with_id2

        Renews a lease, requesting to extend the lease.
        """
        pass

    def test_leases_revoke_lease(self) -> None:
        """Test case for leases_revoke_lease

        Revokes a lease immediately.
        """
        pass

    def test_leases_revoke_lease2(self) -> None:
        """Test case for leases_revoke_lease2

        Revokes a lease immediately.
        """
        pass

    def test_leases_revoke_lease_with_id(self) -> None:
        """Test case for leases_revoke_lease_with_id

        Revokes a lease immediately.
        """
        pass

    def test_leases_revoke_lease_with_id2(self) -> None:
        """Test case for leases_revoke_lease_with_id2

        Revokes a lease immediately.
        """
        pass

    def test_leases_revoke_lease_with_prefix(self) -> None:
        """Test case for leases_revoke_lease_with_prefix

        Revokes all secrets (via a lease ID prefix) or tokens (via the tokens' path property) generated under a given prefix immediately.
        """
        pass

    def test_leases_revoke_lease_with_prefix2(self) -> None:
        """Test case for leases_revoke_lease_with_prefix2

        Revokes all secrets (via a lease ID prefix) or tokens (via the tokens' path property) generated under a given prefix immediately.
        """
        pass

    def test_leases_tidy(self) -> None:
        """Test case for leases_tidy

        """
        pass

    def test_list_experimental_features(self) -> None:
        """Test case for list_experimental_features

        Returns the available and enabled experiments
        """
        pass

    def test_locked_users_list(self) -> None:
        """Test case for locked_users_list

        Report the locked user count metrics, for this namespace and all child namespaces.
        """
        pass

    def test_locked_users_unlock(self) -> None:
        """Test case for locked_users_unlock

        Unlocks the user with given mount_accessor and alias_identifier
        """
        pass

    def test_loggers_read_verbosity_level(self) -> None:
        """Test case for loggers_read_verbosity_level

        Read the log level for all existing loggers.
        """
        pass

    def test_loggers_read_verbosity_level_for(self) -> None:
        """Test case for loggers_read_verbosity_level_for

        Read the log level for a single logger.
        """
        pass

    def test_loggers_revert_verbosity_level(self) -> None:
        """Test case for loggers_revert_verbosity_level

        Revert the all loggers to use log level provided in config.
        """
        pass

    def test_loggers_revert_verbosity_level_for(self) -> None:
        """Test case for loggers_revert_verbosity_level_for

        Revert a single logger to use log level provided in config.
        """
        pass

    def test_loggers_update_verbosity_level(self) -> None:
        """Test case for loggers_update_verbosity_level

        Modify the log level for all existing loggers.
        """
        pass

    def test_loggers_update_verbosity_level_for(self) -> None:
        """Test case for loggers_update_verbosity_level_for

        Modify the log level of a single logger.
        """
        pass

    def test_metrics(self) -> None:
        """Test case for metrics

        """
        pass

    def test_mfa_validate(self) -> None:
        """Test case for mfa_validate

        Validates the login for the given MFA methods. Upon successful validation, it returns an auth response containing the client token
        """
        pass

    def test_monitor(self) -> None:
        """Test case for monitor

        """
        pass

    def test_mounts_disable_secrets_engine(self) -> None:
        """Test case for mounts_disable_secrets_engine

        Disable the mount point specified at the given path.
        """
        pass

    def test_mounts_enable_secrets_engine(self) -> None:
        """Test case for mounts_enable_secrets_engine

        Enable a new secrets engine at the given path.
        """
        pass

    def test_mounts_list_secrets_engines(self) -> None:
        """Test case for mounts_list_secrets_engines

        """
        pass

    def test_mounts_read_configuration(self) -> None:
        """Test case for mounts_read_configuration

        Read the configuration of the secret engine at the given path.
        """
        pass

    def test_mounts_read_tuning_information(self) -> None:
        """Test case for mounts_read_tuning_information

        """
        pass

    def test_mounts_tune_configuration_parameters(self) -> None:
        """Test case for mounts_tune_configuration_parameters

        """
        pass

    def test_plugins_catalog_list_plugins(self) -> None:
        """Test case for plugins_catalog_list_plugins

        """
        pass

    def test_plugins_catalog_list_plugins_with_type(self) -> None:
        """Test case for plugins_catalog_list_plugins_with_type

        List the plugins in the catalog.
        """
        pass

    def test_plugins_catalog_read_plugin_configuration(self) -> None:
        """Test case for plugins_catalog_read_plugin_configuration

        Return the configuration data for the plugin with the given name.
        """
        pass

    def test_plugins_catalog_read_plugin_configuration_with_type(self) -> None:
        """Test case for plugins_catalog_read_plugin_configuration_with_type

        Return the configuration data for the plugin with the given name.
        """
        pass

    def test_plugins_catalog_register_plugin(self) -> None:
        """Test case for plugins_catalog_register_plugin

        Register a new plugin, or updates an existing one with the supplied name.
        """
        pass

    def test_plugins_catalog_register_plugin_with_type(self) -> None:
        """Test case for plugins_catalog_register_plugin_with_type

        Register a new plugin, or updates an existing one with the supplied name.
        """
        pass

    def test_plugins_catalog_remove_plugin(self) -> None:
        """Test case for plugins_catalog_remove_plugin

        Remove the plugin with the given name.
        """
        pass

    def test_plugins_catalog_remove_plugin_with_type(self) -> None:
        """Test case for plugins_catalog_remove_plugin_with_type

        Remove the plugin with the given name.
        """
        pass

    def test_plugins_reload_backends(self) -> None:
        """Test case for plugins_reload_backends

        Reload mounted plugin backends.
        """
        pass

    def test_plugins_runtimes_catalog_list_plugins_runtimes(self) -> None:
        """Test case for plugins_runtimes_catalog_list_plugins_runtimes

        """
        pass

    def test_plugins_runtimes_catalog_read_plugin_runtime_configuration(self) -> None:
        """Test case for plugins_runtimes_catalog_read_plugin_runtime_configuration

        Return the configuration data for the plugin runtime with the given name.
        """
        pass

    def test_plugins_runtimes_catalog_register_plugin_runtime(self) -> None:
        """Test case for plugins_runtimes_catalog_register_plugin_runtime

        Register a new plugin runtime, or updates an existing one with the supplied name.
        """
        pass

    def test_plugins_runtimes_catalog_remove_plugin_runtime(self) -> None:
        """Test case for plugins_runtimes_catalog_remove_plugin_runtime

        Remove the plugin runtime with the given name.
        """
        pass

    def test_policies_delete_acl_policy(self) -> None:
        """Test case for policies_delete_acl_policy

        Delete the ACL policy with the given name.
        """
        pass

    def test_policies_delete_acl_policy2(self) -> None:
        """Test case for policies_delete_acl_policy2

        Delete the policy with the given name.
        """
        pass

    def test_policies_delete_password_policy(self) -> None:
        """Test case for policies_delete_password_policy

        Delete a password policy.
        """
        pass

    def test_policies_generate_password_from_password_policy(self) -> None:
        """Test case for policies_generate_password_from_password_policy

        Generate a password from an existing password policy.
        """
        pass

    def test_policies_list_acl_policies(self) -> None:
        """Test case for policies_list_acl_policies

        """
        pass

    def test_policies_list_acl_policies2(self) -> None:
        """Test case for policies_list_acl_policies2

        """
        pass

    def test_policies_list_acl_policies3(self) -> None:
        """Test case for policies_list_acl_policies3

        """
        pass

    def test_policies_list_password_policies(self) -> None:
        """Test case for policies_list_password_policies

        List the existing password policies.
        """
        pass

    def test_policies_read_acl_policy(self) -> None:
        """Test case for policies_read_acl_policy

        Retrieve information about the named ACL policy.
        """
        pass

    def test_policies_read_acl_policy2(self) -> None:
        """Test case for policies_read_acl_policy2

        Retrieve the policy body for the named policy.
        """
        pass

    def test_policies_read_password_policy(self) -> None:
        """Test case for policies_read_password_policy

        Retrieve an existing password policy.
        """
        pass

    def test_policies_write_acl_policy(self) -> None:
        """Test case for policies_write_acl_policy

        Add a new or update an existing ACL policy.
        """
        pass

    def test_policies_write_acl_policy2(self) -> None:
        """Test case for policies_write_acl_policy2

        Add a new or update an existing policy.
        """
        pass

    def test_policies_write_password_policy(self) -> None:
        """Test case for policies_write_password_policy

        Add a new or update an existing password policy.
        """
        pass

    def test_pprof_blocking(self) -> None:
        """Test case for pprof_blocking

        Returns stack traces that led to blocking on synchronization primitives
        """
        pass

    def test_pprof_command_line(self) -> None:
        """Test case for pprof_command_line

        Returns the running program's command line.
        """
        pass

    def test_pprof_cpu_profile(self) -> None:
        """Test case for pprof_cpu_profile

        Returns a pprof-formatted cpu profile payload.
        """
        pass

    def test_pprof_execution_trace(self) -> None:
        """Test case for pprof_execution_trace

        Returns the execution trace in binary form.
        """
        pass

    def test_pprof_goroutines(self) -> None:
        """Test case for pprof_goroutines

        Returns stack traces of all current goroutines.
        """
        pass

    def test_pprof_index(self) -> None:
        """Test case for pprof_index

        Returns an HTML page listing the available profiles.
        """
        pass

    def test_pprof_memory_allocations(self) -> None:
        """Test case for pprof_memory_allocations

        Returns a sampling of all past memory allocations.
        """
        pass

    def test_pprof_memory_allocations_live(self) -> None:
        """Test case for pprof_memory_allocations_live

        Returns a sampling of memory allocations of live object.
        """
        pass

    def test_pprof_mutexes(self) -> None:
        """Test case for pprof_mutexes

        Returns stack traces of holders of contended mutexes
        """
        pass

    def test_pprof_symbols(self) -> None:
        """Test case for pprof_symbols

        Returns the program counters listed in the request.
        """
        pass

    def test_pprof_thread_creations(self) -> None:
        """Test case for pprof_thread_creations

        Returns stack traces that led to the creation of new OS threads
        """
        pass

    def test_query_token_accessor_capabilities(self) -> None:
        """Test case for query_token_accessor_capabilities

        """
        pass

    def test_query_token_capabilities(self) -> None:
        """Test case for query_token_capabilities

        """
        pass

    def test_query_token_self_capabilities(self) -> None:
        """Test case for query_token_self_capabilities

        """
        pass

    def test_rate_limit_quotas_configure(self) -> None:
        """Test case for rate_limit_quotas_configure

        """
        pass

    def test_rate_limit_quotas_delete(self) -> None:
        """Test case for rate_limit_quotas_delete

        """
        pass

    def test_rate_limit_quotas_list(self) -> None:
        """Test case for rate_limit_quotas_list

        """
        pass

    def test_rate_limit_quotas_read(self) -> None:
        """Test case for rate_limit_quotas_read

        """
        pass

    def test_rate_limit_quotas_read_configuration(self) -> None:
        """Test case for rate_limit_quotas_read_configuration

        """
        pass

    def test_rate_limit_quotas_write(self) -> None:
        """Test case for rate_limit_quotas_write

        """
        pass

    def test_raw_delete(self) -> None:
        """Test case for raw_delete

        Delete the key with given path.
        """
        pass

    def test_raw_list(self) -> None:
        """Test case for raw_list

        Return a list keys for a given path prefix.
        """
        pass

    def test_raw_read(self) -> None:
        """Test case for raw_read

        Read the value of the key at the given path.
        """
        pass

    def test_raw_write(self) -> None:
        """Test case for raw_write

        Update the value of the key at the given path.
        """
        pass

    def test_read_health_status(self) -> None:
        """Test case for read_health_status

        Returns the health status of Vault.
        """
        pass

    def test_read_initialization_status(self) -> None:
        """Test case for read_initialization_status

        Returns the initialization status of Vault.
        """
        pass

    def test_read_replication_status(self) -> None:
        """Test case for read_replication_status

        """
        pass

    def test_read_sanitized_configuration_state(self) -> None:
        """Test case for read_sanitized_configuration_state

        Return a sanitized version of the Vault server configuration.
        """
        pass

    def test_read_wrapping_properties(self) -> None:
        """Test case for read_wrapping_properties

        Look up wrapping properties for the given token.
        """
        pass

    def test_read_wrapping_properties2(self) -> None:
        """Test case for read_wrapping_properties2

        Look up wrapping properties for the requester's token.
        """
        pass

    def test_rekey_attempt_cancel(self) -> None:
        """Test case for rekey_attempt_cancel

        Cancels any in-progress rekey.
        """
        pass

    def test_rekey_attempt_initialize(self) -> None:
        """Test case for rekey_attempt_initialize

        Initializes a new rekey attempt.
        """
        pass

    def test_rekey_attempt_read_progress(self) -> None:
        """Test case for rekey_attempt_read_progress

        Reads the configuration and progress of the current rekey attempt.
        """
        pass

    def test_rekey_attempt_update(self) -> None:
        """Test case for rekey_attempt_update

        Enter a single unseal key share to progress the rekey of the Vault.
        """
        pass

    def test_rekey_delete_backup_key(self) -> None:
        """Test case for rekey_delete_backup_key

        Delete the backup copy of PGP-encrypted unseal keys.
        """
        pass

    def test_rekey_delete_backup_recovery_key(self) -> None:
        """Test case for rekey_delete_backup_recovery_key

        """
        pass

    def test_rekey_read_backup_key(self) -> None:
        """Test case for rekey_read_backup_key

        Return the backup copy of PGP-encrypted unseal keys.
        """
        pass

    def test_rekey_read_backup_recovery_key(self) -> None:
        """Test case for rekey_read_backup_recovery_key

        """
        pass

    def test_rekey_verification_cancel(self) -> None:
        """Test case for rekey_verification_cancel

        Cancel any in-progress rekey verification operation.
        """
        pass

    def test_rekey_verification_read_progress(self) -> None:
        """Test case for rekey_verification_read_progress

        Read the configuration and progress of the current rekey verification attempt.
        """
        pass

    def test_rekey_verification_update(self) -> None:
        """Test case for rekey_verification_update

        Enter a single new key share to progress the rekey verification operation.
        """
        pass

    def test_reload_subsystem(self) -> None:
        """Test case for reload_subsystem

        Reload the given subsystem
        """
        pass

    def test_remount(self) -> None:
        """Test case for remount

        Initiate a mount migration
        """
        pass

    def test_remount_status(self) -> None:
        """Test case for remount_status

        Check status of a mount migration
        """
        pass

    def test_rewrap(self) -> None:
        """Test case for rewrap

        """
        pass

    def test_root_token_generation_cancel(self) -> None:
        """Test case for root_token_generation_cancel

        Cancels any in-progress root generation attempt.
        """
        pass

    def test_root_token_generation_cancel2(self) -> None:
        """Test case for root_token_generation_cancel2

        Cancels any in-progress root generation attempt.
        """
        pass

    def test_root_token_generation_initialize(self) -> None:
        """Test case for root_token_generation_initialize

        Initializes a new root generation attempt.
        """
        pass

    def test_root_token_generation_initialize2(self) -> None:
        """Test case for root_token_generation_initialize2

        Initializes a new root generation attempt.
        """
        pass

    def test_root_token_generation_read_progress(self) -> None:
        """Test case for root_token_generation_read_progress

        Read the configuration and progress of the current root generation attempt.
        """
        pass

    def test_root_token_generation_read_progress2(self) -> None:
        """Test case for root_token_generation_read_progress2

        Read the configuration and progress of the current root generation attempt.
        """
        pass

    def test_root_token_generation_update(self) -> None:
        """Test case for root_token_generation_update

        Enter a single unseal key share to progress the root generation attempt.
        """
        pass

    def test_seal(self) -> None:
        """Test case for seal

        Seal the Vault.
        """
        pass

    def test_seal_status(self) -> None:
        """Test case for seal_status

        Check the seal status of a Vault.
        """
        pass

    def test_step_down_leader(self) -> None:
        """Test case for step_down_leader

        Cause the node to give up active status.
        """
        pass

    def test_ui_headers_configure(self) -> None:
        """Test case for ui_headers_configure

        Configure the values to be returned for the UI header.
        """
        pass

    def test_ui_headers_delete_configuration(self) -> None:
        """Test case for ui_headers_delete_configuration

        Remove a UI header.
        """
        pass

    def test_ui_headers_list(self) -> None:
        """Test case for ui_headers_list

        Return a list of configured UI headers.
        """
        pass

    def test_ui_headers_read_configuration(self) -> None:
        """Test case for ui_headers_read_configuration

        Return the given UI header's configuration
        """
        pass

    def test_unseal(self) -> None:
        """Test case for unseal

        Unseal the Vault.
        """
        pass

    def test_unwrap(self) -> None:
        """Test case for unwrap

        """
        pass

    def test_version_history(self) -> None:
        """Test case for version_history

        Returns map of historical version change entries
        """
        pass

    def test_wrap(self) -> None:
        """Test case for wrap

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiReadClusterConfigurationResponse(BaseModel):
    """
    PkiReadClusterConfigurationResponse
    """ # noqa: E501
    aia_path: Optional[StrictStr] = Field(default=None, description="Optional URI to this mount's AIA distribution point; may refer to an external non-Vault responder. This is for resolving AIA URLs and providing the {{cluster_aia_path}} template parameter and will not be used for other purposes. As such, unlike path above, this could safely be an insecure transit mechanism (like HTTP without TLS). For example: http://cdn.example.com/pr1/pki")
    path: Optional[StrictStr] = Field(default=None, description="Canonical URI to this mount on this performance replication cluster's external address. This is for resolving AIA URLs and providing the {{cluster_path}} template parameter but might be used for other purposes in the future. This should only point back to this particular PR replica and should not ever point to another PR cluster. It may point to any node in the PR replica, including standby nodes, and need not always point to the active node. For example: https://pr1.vault.example.com:8200/v1/pki")
    __properties: ClassVar[List[str]] = ["aia_path", "path"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiReadClusterConfigurationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiReadClusterConfigurationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aia_path": obj.get("aia_path"),
            "path": obj.get("path")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class KubernetesWriteRoleRequest(BaseModel):
    """
    KubernetesWriteRoleRequest
    """ # noqa: E501
    allowed_kubernetes_namespace_selector: Optional[StrictStr] = Field(default=None, description="A label selector for Kubernetes namespaces in which credentials can be generated. Accepts either a JSON or YAML object. If set with allowed_kubernetes_namespaces, the conditions are conjuncted.")
    allowed_kubernetes_namespaces: Optional[List[StrictStr]] = Field(default=None, description="A list of the Kubernetes namespaces in which credentials can be generated. If set to \"*\" all namespaces are allowed.")
    extra_annotations: Optional[Dict[str, Any]] = Field(default=None, description="Additional annotations to apply to all generated Kubernetes objects.")
    extra_labels: Optional[Dict[str, Any]] = Field(default=None, description="Additional labels to apply to all generated Kubernetes objects.")
    generated_role_rules: Optional[StrictStr] = Field(default=None, description="The Role or ClusterRole rules to use when generating a role. Accepts either a JSON or YAML object. If set, the entire chain of Kubernetes objects will be generated.")
    kubernetes_role_name: Optional[StrictStr] = Field(default=None, description="The pre-existing Role or ClusterRole to bind a generated service account to. If set, Kubernetes token, service account, and role binding objects will be created.")
    kubernetes_role_type: Optional[StrictStr] = Field(default='Role', description="Specifies whether the Kubernetes role is a Role or ClusterRole.")
    name_template: Optional[StrictStr] = Field(default=None, description="The name template to use when generating service accounts, roles and role bindings. If unset, a default template is used.")
    service_account_name: Optional[StrictStr] = Field(default=None, description="The pre-existing service account to generate tokens for. Mutually exclusive with all role parameters. If set, only a Kubernetes service account token will be created.")
    token_default_audiences: Optional[List[StrictStr]] = Field(default=None, description="The default audiences for generated Kubernetes service account tokens. If not set or set to \"\", will use k8s cluster default.")
    token_default_ttl: Optional[StrictStr] = Field(default=None, description="The default ttl for generated Kubernetes service account tokens. If not set or set to 0, will use system default.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum ttl for generated Kubernetes service account tokens. If not set or set to 0, will use system default.")
    __properties: ClassVar[List[str]] = ["allowed_kubernetes_namespace_selector", "allowed_kubernetes_namespaces", "extra_annotations", "extra_labels", "generated_role_rules", "kubernetes_role_name", "kubernetes_role_type", "name_template", "service_account_name", "token_default_audiences", "token_default_ttl", "token_max_ttl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of KubernetesWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of KubernetesWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowed_kubernetes_namespace_selector": obj.get("allowed_kubernetes_namespace_selector"),
            "allowed_kubernetes_namespaces": obj.get("allowed_kubernetes_namespaces"),
            "extra_annotations": obj.get("extra_annotations"),
            "extra_labels": obj.get("extra_labels"),
            "generated_role_rules": obj.get("generated_role_rules"),
            "kubernetes_role_name": obj.get("kubernetes_role_name"),
            "kubernetes_role_type": obj.get("kubernetes_role_type") if obj.get("kubernetes_role_type") is not None else 'Role',
            "name_template": obj.get("name_template"),
            "service_account_name": obj.get("service_account_name"),
            "token_default_audiences": obj.get("token_default_audiences"),
            "token_default_ttl": obj.get("token_default_ttl"),
            "token_max_ttl": obj.get("token_max_ttl")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TransitRewrapRequest(BaseModel):
    """
    TransitRewrapRequest
    """ # noqa: E501
    batch_input: Optional[List[Dict[str, Any]]] = Field(default=None, description="Specifies a list of items to be re-encrypted in a single batch. When this parameter is set, if the parameters 'ciphertext', 'context' and 'nonce' are also set, they will be ignored. Any batch output will preserve the order of the batch input.")
    ciphertext: Optional[StrictStr] = Field(default=None, description="Ciphertext value to rewrap")
    context: Optional[StrictStr] = Field(default=None, description="Base64 encoded context for key derivation. Required for derived keys.")
    key_version: Optional[StrictInt] = Field(default=None, description="The version of the key to use for encryption. Must be 0 (for latest) or a value greater than or equal to the min_encryption_version configured on the key.")
    nonce: Optional[StrictStr] = Field(default=None, description="Nonce for when convergent encryption is used")
    __properties: ClassVar[List[str]] = ["batch_input", "ciphertext", "context", "key_version", "nonce"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransitRewrapRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransitRewrapRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "batch_input": obj.get("batch_input"),
            "ciphertext": obj.get("ciphertext"),
            "context": obj.get("context"),
            "key_version": obj.get("key_version"),
            "nonce": obj.get("nonce")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.api.secrets_api import SecretsApi


class TestSecretsApi(unittest.TestCase):
    """SecretsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SecretsApi()

    def tearDown(self) -> None:
        pass

    def test_ali_cloud_configure(self) -> None:
        """Test case for ali_cloud_configure

        """
        pass

    def test_ali_cloud_delete_configuration(self) -> None:
        """Test case for ali_cloud_delete_configuration

        """
        pass

    def test_ali_cloud_delete_role(self) -> None:
        """Test case for ali_cloud_delete_role

        Read, write and reference policies and roles that API keys or STS credentials can be made for.
        """
        pass

    def test_ali_cloud_generate_credentials(self) -> None:
        """Test case for ali_cloud_generate_credentials

        Generate an API key or STS credential using the given role's configuration.'
        """
        pass

    def test_ali_cloud_list_roles(self) -> None:
        """Test case for ali_cloud_list_roles

        List the existing roles in this backend.
        """
        pass

    def test_ali_cloud_read_configuration(self) -> None:
        """Test case for ali_cloud_read_configuration

        """
        pass

    def test_ali_cloud_read_role(self) -> None:
        """Test case for ali_cloud_read_role

        Read, write and reference policies and roles that API keys or STS credentials can be made for.
        """
        pass

    def test_ali_cloud_write_role(self) -> None:
        """Test case for ali_cloud_write_role

        Read, write and reference policies and roles that API keys or STS credentials can be made for.
        """
        pass

    def test_aws_configure_lease(self) -> None:
        """Test case for aws_configure_lease

        """
        pass

    def test_aws_configure_root_iam_credentials(self) -> None:
        """Test case for aws_configure_root_iam_credentials

        """
        pass

    def test_aws_delete_role(self) -> None:
        """Test case for aws_delete_role

        Read, write and reference IAM policies that access keys can be made for.
        """
        pass

    def test_aws_delete_static_roles_name(self) -> None:
        """Test case for aws_delete_static_roles_name

        """
        pass

    def test_aws_generate_credentials(self) -> None:
        """Test case for aws_generate_credentials

        """
        pass

    def test_aws_generate_credentials_with_parameters(self) -> None:
        """Test case for aws_generate_credentials_with_parameters

        """
        pass

    def test_aws_generate_sts_credentials(self) -> None:
        """Test case for aws_generate_sts_credentials

        """
        pass

    def test_aws_generate_sts_credentials_with_parameters(self) -> None:
        """Test case for aws_generate_sts_credentials_with_parameters

        """
        pass

    def test_aws_list_roles(self) -> None:
        """Test case for aws_list_roles

        List the existing roles in this backend
        """
        pass

    def test_aws_read_lease_configuration(self) -> None:
        """Test case for aws_read_lease_configuration

        """
        pass

    def test_aws_read_role(self) -> None:
        """Test case for aws_read_role

        Read, write and reference IAM policies that access keys can be made for.
        """
        pass

    def test_aws_read_root_iam_credentials_configuration(self) -> None:
        """Test case for aws_read_root_iam_credentials_configuration

        """
        pass

    def test_aws_read_static_creds_name(self) -> None:
        """Test case for aws_read_static_creds_name

        """
        pass

    def test_aws_read_static_roles_name(self) -> None:
        """Test case for aws_read_static_roles_name

        """
        pass

    def test_aws_rotate_root_iam_credentials(self) -> None:
        """Test case for aws_rotate_root_iam_credentials

        """
        pass

    def test_aws_write_role(self) -> None:
        """Test case for aws_write_role

        Read, write and reference IAM policies that access keys can be made for.
        """
        pass

    def test_aws_write_static_roles_name(self) -> None:
        """Test case for aws_write_static_roles_name

        """
        pass

    def test_azure_configure(self) -> None:
        """Test case for azure_configure

        """
        pass

    def test_azure_delete_configuration(self) -> None:
        """Test case for azure_delete_configuration

        """
        pass

    def test_azure_delete_role(self) -> None:
        """Test case for azure_delete_role

        Manage the Vault roles used to generate Azure credentials.
        """
        pass

    def test_azure_list_roles(self) -> None:
        """Test case for azure_list_roles

        List existing roles.
        """
        pass

    def test_azure_read_configuration(self) -> None:
        """Test case for azure_read_configuration

        """
        pass

    def test_azure_read_role(self) -> None:
        """Test case for azure_read_role

        Manage the Vault roles used to generate Azure credentials.
        """
        pass

    def test_azure_request_service_principal_credentials(self) -> None:
        """Test case for azure_request_service_principal_credentials

        """
        pass

    def test_azure_rotate_root(self) -> None:
        """Test case for azure_rotate_root

        """
        pass

    def test_azure_write_role(self) -> None:
        """Test case for azure_write_role

        Manage the Vault roles used to generate Azure credentials.
        """
        pass

    def test_consul_configure_access(self) -> None:
        """Test case for consul_configure_access

        """
        pass

    def test_consul_delete_role(self) -> None:
        """Test case for consul_delete_role

        """
        pass

    def test_consul_generate_credentials(self) -> None:
        """Test case for consul_generate_credentials

        """
        pass

    def test_consul_list_roles(self) -> None:
        """Test case for consul_list_roles

        """
        pass

    def test_consul_read_access_configuration(self) -> None:
        """Test case for consul_read_access_configuration

        """
        pass

    def test_consul_read_role(self) -> None:
        """Test case for consul_read_role

        """
        pass

    def test_consul_write_role(self) -> None:
        """Test case for consul_write_role

        """
        pass

    def test_cubbyhole_delete(self) -> None:
        """Test case for cubbyhole_delete

        Deletes the secret at the specified location.
        """
        pass

    def test_cubbyhole_list(self) -> None:
        """Test case for cubbyhole_list

        List secret entries at the specified location.
        """
        pass

    def test_cubbyhole_read(self) -> None:
        """Test case for cubbyhole_read

        Retrieve the secret at the specified location.
        """
        pass

    def test_cubbyhole_write(self) -> None:
        """Test case for cubbyhole_write

        Store a secret at the specified location.
        """
        pass

    def test_database_configure_connection(self) -> None:
        """Test case for database_configure_connection

        """
        pass

    def test_database_delete_connection_configuration(self) -> None:
        """Test case for database_delete_connection_configuration

        """
        pass

    def test_database_delete_role(self) -> None:
        """Test case for database_delete_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_database_delete_static_role(self) -> None:
        """Test case for database_delete_static_role

        Manage the static roles that can be created with this backend.
        """
        pass

    def test_database_generate_credentials(self) -> None:
        """Test case for database_generate_credentials

        Request database credentials for a certain role.
        """
        pass

    def test_database_list_connections(self) -> None:
        """Test case for database_list_connections

        Configure connection details to a database plugin.
        """
        pass

    def test_database_list_roles(self) -> None:
        """Test case for database_list_roles

        Manage the roles that can be created with this backend.
        """
        pass

    def test_database_list_static_roles(self) -> None:
        """Test case for database_list_static_roles

        Manage the static roles that can be created with this backend.
        """
        pass

    def test_database_read_connection_configuration(self) -> None:
        """Test case for database_read_connection_configuration

        """
        pass

    def test_database_read_role(self) -> None:
        """Test case for database_read_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_database_read_static_role(self) -> None:
        """Test case for database_read_static_role

        Manage the static roles that can be created with this backend.
        """
        pass

    def test_database_read_static_role_credentials(self) -> None:
        """Test case for database_read_static_role_credentials

        Request database credentials for a certain static role. These credentials are rotated periodically.
        """
        pass

    def test_database_reset_connection(self) -> None:
        """Test case for database_reset_connection

        Resets a database plugin.
        """
        pass

    def test_database_rotate_root_credentials(self) -> None:
        """Test case for database_rotate_root_credentials

        """
        pass

    def test_database_rotate_static_role_credentials(self) -> None:
        """Test case for database_rotate_static_role_credentials

        """
        pass

    def test_database_write_role(self) -> None:
        """Test case for database_write_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_database_write_static_role(self) -> None:
        """Test case for database_write_static_role

        Manage the static roles that can be created with this backend.
        """
        pass

    def test_google_cloud_configure(self) -> None:
        """Test case for google_cloud_configure

        """
        pass

    def test_google_cloud_delete_impersonated_account(self) -> None:
        """Test case for google_cloud_delete_impersonated_account

        """
        pass

    def test_google_cloud_delete_roleset(self) -> None:
        """Test case for google_cloud_delete_roleset

        """
        pass

    def test_google_cloud_delete_static_account(self) -> None:
        """Test case for google_cloud_delete_static_account

        """
        pass

    def test_google_cloud_generate_impersonated_account_access_token(self) -> None:
        """Test case for google_cloud_generate_impersonated_account_access_token

        """
        pass

    def test_google_cloud_generate_impersonated_account_access_token2(self) -> None:
        """Test case for google_cloud_generate_impersonated_account_access_token2

        """
        pass

    def test_google_cloud_generate_roleset_access_token(self) -> None:
        """Test case for google_cloud_generate_roleset_access_token

        """
        pass

    def test_google_cloud_generate_roleset_access_token2(self) -> None:
        """Test case for google_cloud_generate_roleset_access_token2

        """
        pass

    def test_google_cloud_generate_roleset_access_token3(self) -> None:
        """Test case for google_cloud_generate_roleset_access_token3

        """
        pass

    def test_google_cloud_generate_roleset_access_token4(self) -> None:
        """Test case for google_cloud_generate_roleset_access_token4

        """
        pass

    def test_google_cloud_generate_roleset_key(self) -> None:
        """Test case for google_cloud_generate_roleset_key

        """
        pass

    def test_google_cloud_generate_roleset_key2(self) -> None:
        """Test case for google_cloud_generate_roleset_key2

        """
        pass

    def test_google_cloud_generate_roleset_key3(self) -> None:
        """Test case for google_cloud_generate_roleset_key3

        """
        pass

    def test_google_cloud_generate_roleset_key4(self) -> None:
        """Test case for google_cloud_generate_roleset_key4

        """
        pass

    def test_google_cloud_generate_static_account_access_token(self) -> None:
        """Test case for google_cloud_generate_static_account_access_token

        """
        pass

    def test_google_cloud_generate_static_account_access_token2(self) -> None:
        """Test case for google_cloud_generate_static_account_access_token2

        """
        pass

    def test_google_cloud_generate_static_account_key(self) -> None:
        """Test case for google_cloud_generate_static_account_key

        """
        pass

    def test_google_cloud_generate_static_account_key2(self) -> None:
        """Test case for google_cloud_generate_static_account_key2

        """
        pass

    def test_google_cloud_kms_configure(self) -> None:
        """Test case for google_cloud_kms_configure

        """
        pass

    def test_google_cloud_kms_configure_key(self) -> None:
        """Test case for google_cloud_kms_configure_key

        """
        pass

    def test_google_cloud_kms_decrypt(self) -> None:
        """Test case for google_cloud_kms_decrypt

        Decrypt a ciphertext value using a named key
        """
        pass

    def test_google_cloud_kms_delete_configuration(self) -> None:
        """Test case for google_cloud_kms_delete_configuration

        """
        pass

    def test_google_cloud_kms_delete_key(self) -> None:
        """Test case for google_cloud_kms_delete_key

        Interact with crypto keys in Vault and Google Cloud KMS
        """
        pass

    def test_google_cloud_kms_deregister_key(self) -> None:
        """Test case for google_cloud_kms_deregister_key

        """
        pass

    def test_google_cloud_kms_deregister_key2(self) -> None:
        """Test case for google_cloud_kms_deregister_key2

        """
        pass

    def test_google_cloud_kms_encrypt(self) -> None:
        """Test case for google_cloud_kms_encrypt

        Encrypt a plaintext value using a named key
        """
        pass

    def test_google_cloud_kms_list_keys(self) -> None:
        """Test case for google_cloud_kms_list_keys

        List named keys
        """
        pass

    def test_google_cloud_kms_read_configuration(self) -> None:
        """Test case for google_cloud_kms_read_configuration

        """
        pass

    def test_google_cloud_kms_read_key(self) -> None:
        """Test case for google_cloud_kms_read_key

        Interact with crypto keys in Vault and Google Cloud KMS
        """
        pass

    def test_google_cloud_kms_read_key_configuration(self) -> None:
        """Test case for google_cloud_kms_read_key_configuration

        """
        pass

    def test_google_cloud_kms_reencrypt(self) -> None:
        """Test case for google_cloud_kms_reencrypt

        Re-encrypt existing ciphertext data to a new version
        """
        pass

    def test_google_cloud_kms_register_key(self) -> None:
        """Test case for google_cloud_kms_register_key

        Register an existing crypto key in Google Cloud KMS
        """
        pass

    def test_google_cloud_kms_retrieve_public_key(self) -> None:
        """Test case for google_cloud_kms_retrieve_public_key

        Retrieve the public key associated with the named key
        """
        pass

    def test_google_cloud_kms_rotate_key(self) -> None:
        """Test case for google_cloud_kms_rotate_key

        Rotate a crypto key to a new primary version
        """
        pass

    def test_google_cloud_kms_sign(self) -> None:
        """Test case for google_cloud_kms_sign

        Signs a message or digest using a named key
        """
        pass

    def test_google_cloud_kms_trim_key_versions(self) -> None:
        """Test case for google_cloud_kms_trim_key_versions

        """
        pass

    def test_google_cloud_kms_trim_key_versions2(self) -> None:
        """Test case for google_cloud_kms_trim_key_versions2

        """
        pass

    def test_google_cloud_kms_verify(self) -> None:
        """Test case for google_cloud_kms_verify

        Verify a signature using a named key
        """
        pass

    def test_google_cloud_kms_write_key(self) -> None:
        """Test case for google_cloud_kms_write_key

        Interact with crypto keys in Vault and Google Cloud KMS
        """
        pass

    def test_google_cloud_list_impersonated_accounts(self) -> None:
        """Test case for google_cloud_list_impersonated_accounts

        """
        pass

    def test_google_cloud_list_impersonated_accounts2(self) -> None:
        """Test case for google_cloud_list_impersonated_accounts2

        """
        pass

    def test_google_cloud_list_rolesets(self) -> None:
        """Test case for google_cloud_list_rolesets

        """
        pass

    def test_google_cloud_list_rolesets2(self) -> None:
        """Test case for google_cloud_list_rolesets2

        """
        pass

    def test_google_cloud_list_static_accounts(self) -> None:
        """Test case for google_cloud_list_static_accounts

        """
        pass

    def test_google_cloud_list_static_accounts2(self) -> None:
        """Test case for google_cloud_list_static_accounts2

        """
        pass

    def test_google_cloud_read_configuration(self) -> None:
        """Test case for google_cloud_read_configuration

        """
        pass

    def test_google_cloud_read_impersonated_account(self) -> None:
        """Test case for google_cloud_read_impersonated_account

        """
        pass

    def test_google_cloud_read_roleset(self) -> None:
        """Test case for google_cloud_read_roleset

        """
        pass

    def test_google_cloud_read_static_account(self) -> None:
        """Test case for google_cloud_read_static_account

        """
        pass

    def test_google_cloud_rotate_roleset(self) -> None:
        """Test case for google_cloud_rotate_roleset

        """
        pass

    def test_google_cloud_rotate_roleset_key(self) -> None:
        """Test case for google_cloud_rotate_roleset_key

        """
        pass

    def test_google_cloud_rotate_root_credentials(self) -> None:
        """Test case for google_cloud_rotate_root_credentials

        """
        pass

    def test_google_cloud_rotate_static_account_key(self) -> None:
        """Test case for google_cloud_rotate_static_account_key

        """
        pass

    def test_google_cloud_write_impersonated_account(self) -> None:
        """Test case for google_cloud_write_impersonated_account

        """
        pass

    def test_google_cloud_write_roleset(self) -> None:
        """Test case for google_cloud_write_roleset

        """
        pass

    def test_google_cloud_write_static_account(self) -> None:
        """Test case for google_cloud_write_static_account

        """
        pass

    def test_kubernetes_check_configuration(self) -> None:
        """Test case for kubernetes_check_configuration

        """
        pass

    def test_kubernetes_configure(self) -> None:
        """Test case for kubernetes_configure

        """
        pass

    def test_kubernetes_delete_configuration(self) -> None:
        """Test case for kubernetes_delete_configuration

        """
        pass

    def test_kubernetes_delete_role(self) -> None:
        """Test case for kubernetes_delete_role

        """
        pass

    def test_kubernetes_generate_credentials(self) -> None:
        """Test case for kubernetes_generate_credentials

        """
        pass

    def test_kubernetes_list_roles(self) -> None:
        """Test case for kubernetes_list_roles

        """
        pass

    def test_kubernetes_read_configuration(self) -> None:
        """Test case for kubernetes_read_configuration

        """
        pass

    def test_kubernetes_read_role(self) -> None:
        """Test case for kubernetes_read_role

        """
        pass

    def test_kubernetes_write_role(self) -> None:
        """Test case for kubernetes_write_role

        """
        pass

    def test_kv_v1_delete(self) -> None:
        """Test case for kv_v1_delete

        """
        pass

    def test_kv_v1_list(self) -> None:
        """Test case for kv_v1_list

        """
        pass

    def test_kv_v1_read(self) -> None:
        """Test case for kv_v1_read

        """
        pass

    def test_kv_v1_write(self) -> None:
        """Test case for kv_v1_write

        """
        pass

    def test_kv_v2_configure(self) -> None:
        """Test case for kv_v2_configure

        Configure backend level settings that are applied to every key in the key-value store.
        """
        pass

    def test_kv_v2_delete(self) -> None:
        """Test case for kv_v2_delete

        """
        pass

    def test_kv_v2_delete_metadata_and_all_versions(self) -> None:
        """Test case for kv_v2_delete_metadata_and_all_versions

        """
        pass

    def test_kv_v2_delete_versions(self) -> None:
        """Test case for kv_v2_delete_versions

        """
        pass

    def test_kv_v2_destroy_versions(self) -> None:
        """Test case for kv_v2_destroy_versions

        """
        pass

    def test_kv_v2_list(self) -> None:
        """Test case for kv_v2_list

        """
        pass

    def test_kv_v2_read(self) -> None:
        """Test case for kv_v2_read

        """
        pass

    def test_kv_v2_read_configuration(self) -> None:
        """Test case for kv_v2_read_configuration

        Read the backend level settings.
        """
        pass

    def test_kv_v2_read_metadata(self) -> None:
        """Test case for kv_v2_read_metadata

        """
        pass

    def test_kv_v2_read_subkeys(self) -> None:
        """Test case for kv_v2_read_subkeys

        """
        pass

    def test_kv_v2_undelete_versions(self) -> None:
        """Test case for kv_v2_undelete_versions

        """
        pass

    def test_kv_v2_write(self) -> None:
        """Test case for kv_v2_write

        """
        pass

    def test_kv_v2_write_metadata(self) -> None:
        """Test case for kv_v2_write_metadata

        """
        pass

    def test_ldap_configure(self) -> None:
        """Test case for ldap_configure

        """
        pass

    def test_ldap_delete_configuration(self) -> None:
        """Test case for ldap_delete_configuration

        """
        pass

    def test_ldap_delete_dynamic_role(self) -> None:
        """Test case for ldap_delete_dynamic_role

        """
        pass

    def test_ldap_delete_static_role(self) -> None:
        """Test case for ldap_delete_static_role

        """
        pass

    def test_ldap_library_check_in(self) -> None:
        """Test case for ldap_library_check_in

        Check service accounts in to the library.
        """
        pass

    def test_ldap_library_check_out(self) -> None:
        """Test case for ldap_library_check_out

        Check a service account out from the library.
        """
        pass

    def test_ldap_library_check_status(self) -> None:
        """Test case for ldap_library_check_status

        Check the status of the service accounts in a library set.
        """
        pass

    def test_ldap_library_configure(self) -> None:
        """Test case for ldap_library_configure

        Update a library set.
        """
        pass

    def test_ldap_library_delete(self) -> None:
        """Test case for ldap_library_delete

        Delete a library set.
        """
        pass

    def test_ldap_library_force_check_in(self) -> None:
        """Test case for ldap_library_force_check_in

        Check service accounts in to the library.
        """
        pass

    def test_ldap_library_list(self) -> None:
        """Test case for ldap_library_list

        """
        pass

    def test_ldap_library_read(self) -> None:
        """Test case for ldap_library_read

        Read a library set.
        """
        pass

    def test_ldap_list_dynamic_roles(self) -> None:
        """Test case for ldap_list_dynamic_roles

        """
        pass

    def test_ldap_list_static_roles(self) -> None:
        """Test case for ldap_list_static_roles

        """
        pass

    def test_ldap_read_configuration(self) -> None:
        """Test case for ldap_read_configuration

        """
        pass

    def test_ldap_read_dynamic_role(self) -> None:
        """Test case for ldap_read_dynamic_role

        """
        pass

    def test_ldap_read_static_role(self) -> None:
        """Test case for ldap_read_static_role

        """
        pass

    def test_ldap_request_dynamic_role_credentials(self) -> None:
        """Test case for ldap_request_dynamic_role_credentials

        """
        pass

    def test_ldap_request_static_role_credentials(self) -> None:
        """Test case for ldap_request_static_role_credentials

        """
        pass

    def test_ldap_rotate_root_credentials(self) -> None:
        """Test case for ldap_rotate_root_credentials

        """
        pass

    def test_ldap_rotate_static_role(self) -> None:
        """Test case for ldap_rotate_static_role

        """
        pass

    def test_ldap_write_dynamic_role(self) -> None:
        """Test case for ldap_write_dynamic_role

        """
        pass

    def test_ldap_write_static_role(self) -> None:
        """Test case for ldap_write_static_role

        """
        pass

    def test_mongo_db_atlas_configure(self) -> None:
        """Test case for mongo_db_atlas_configure

        """
        pass

    def test_mongo_db_atlas_delete_role(self) -> None:
        """Test case for mongo_db_atlas_delete_role

        Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
        """
        pass

    def test_mongo_db_atlas_generate_credentials(self) -> None:
        """Test case for mongo_db_atlas_generate_credentials

        """
        pass

    def test_mongo_db_atlas_generate_credentials2(self) -> None:
        """Test case for mongo_db_atlas_generate_credentials2

        """
        pass

    def test_mongo_db_atlas_list_roles(self) -> None:
        """Test case for mongo_db_atlas_list_roles

        List the existing roles in this backend
        """
        pass

    def test_mongo_db_atlas_read_configuration(self) -> None:
        """Test case for mongo_db_atlas_read_configuration

        """
        pass

    def test_mongo_db_atlas_read_role(self) -> None:
        """Test case for mongo_db_atlas_read_role

        Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
        """
        pass

    def test_mongo_db_atlas_write_role(self) -> None:
        """Test case for mongo_db_atlas_write_role

        Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
        """
        pass

    def test_nomad_configure_access(self) -> None:
        """Test case for nomad_configure_access

        """
        pass

    def test_nomad_configure_lease(self) -> None:
        """Test case for nomad_configure_lease

        """
        pass

    def test_nomad_delete_access_configuration(self) -> None:
        """Test case for nomad_delete_access_configuration

        """
        pass

    def test_nomad_delete_lease_configuration(self) -> None:
        """Test case for nomad_delete_lease_configuration

        """
        pass

    def test_nomad_delete_role(self) -> None:
        """Test case for nomad_delete_role

        """
        pass

    def test_nomad_generate_credentials(self) -> None:
        """Test case for nomad_generate_credentials

        """
        pass

    def test_nomad_list_roles(self) -> None:
        """Test case for nomad_list_roles

        """
        pass

    def test_nomad_read_access_configuration(self) -> None:
        """Test case for nomad_read_access_configuration

        """
        pass

    def test_nomad_read_lease_configuration(self) -> None:
        """Test case for nomad_read_lease_configuration

        """
        pass

    def test_nomad_read_role(self) -> None:
        """Test case for nomad_read_role

        """
        pass

    def test_nomad_write_role(self) -> None:
        """Test case for nomad_write_role

        """
        pass

    def test_pki_configure_acme(self) -> None:
        """Test case for pki_configure_acme

        """
        pass

    def test_pki_configure_auto_tidy(self) -> None:
        """Test case for pki_configure_auto_tidy

        """
        pass

    def test_pki_configure_ca(self) -> None:
        """Test case for pki_configure_ca

        """
        pass

    def test_pki_configure_cluster(self) -> None:
        """Test case for pki_configure_cluster

        """
        pass

    def test_pki_configure_crl(self) -> None:
        """Test case for pki_configure_crl

        """
        pass

    def test_pki_configure_issuers(self) -> None:
        """Test case for pki_configure_issuers

        """
        pass

    def test_pki_configure_keys(self) -> None:
        """Test case for pki_configure_keys

        """
        pass

    def test_pki_configure_urls(self) -> None:
        """Test case for pki_configure_urls

        """
        pass

    def test_pki_cross_sign_intermediate(self) -> None:
        """Test case for pki_cross_sign_intermediate

        """
        pass

    def test_pki_delete_eab_key(self) -> None:
        """Test case for pki_delete_eab_key

        """
        pass

    def test_pki_delete_issuer(self) -> None:
        """Test case for pki_delete_issuer

        """
        pass

    def test_pki_delete_key(self) -> None:
        """Test case for pki_delete_key

        """
        pass

    def test_pki_delete_role(self) -> None:
        """Test case for pki_delete_role

        """
        pass

    def test_pki_delete_root(self) -> None:
        """Test case for pki_delete_root

        """
        pass

    def test_pki_generate_eab_key(self) -> None:
        """Test case for pki_generate_eab_key

        """
        pass

    def test_pki_generate_eab_key_for_issuer(self) -> None:
        """Test case for pki_generate_eab_key_for_issuer

        """
        pass

    def test_pki_generate_eab_key_for_issuer_and_role(self) -> None:
        """Test case for pki_generate_eab_key_for_issuer_and_role

        """
        pass

    def test_pki_generate_eab_key_for_role(self) -> None:
        """Test case for pki_generate_eab_key_for_role

        """
        pass

    def test_pki_generate_exported_key(self) -> None:
        """Test case for pki_generate_exported_key

        """
        pass

    def test_pki_generate_intermediate(self) -> None:
        """Test case for pki_generate_intermediate

        """
        pass

    def test_pki_generate_internal_key(self) -> None:
        """Test case for pki_generate_internal_key

        """
        pass

    def test_pki_generate_kms_key(self) -> None:
        """Test case for pki_generate_kms_key

        """
        pass

    def test_pki_generate_root(self) -> None:
        """Test case for pki_generate_root

        """
        pass

    def test_pki_import_key(self) -> None:
        """Test case for pki_import_key

        """
        pass

    def test_pki_issue_with_role(self) -> None:
        """Test case for pki_issue_with_role

        """
        pass

    def test_pki_issuer_issue_with_role(self) -> None:
        """Test case for pki_issuer_issue_with_role

        """
        pass

    def test_pki_issuer_read_crl(self) -> None:
        """Test case for pki_issuer_read_crl

        """
        pass

    def test_pki_issuer_read_crl_delta(self) -> None:
        """Test case for pki_issuer_read_crl_delta

        """
        pass

    def test_pki_issuer_read_crl_delta_der(self) -> None:
        """Test case for pki_issuer_read_crl_delta_der

        """
        pass

    def test_pki_issuer_read_crl_delta_pem(self) -> None:
        """Test case for pki_issuer_read_crl_delta_pem

        """
        pass

    def test_pki_issuer_read_crl_der(self) -> None:
        """Test case for pki_issuer_read_crl_der

        """
        pass

    def test_pki_issuer_read_crl_pem(self) -> None:
        """Test case for pki_issuer_read_crl_pem

        """
        pass

    def test_pki_issuer_resign_crls(self) -> None:
        """Test case for pki_issuer_resign_crls

        """
        pass

    def test_pki_issuer_sign_intermediate(self) -> None:
        """Test case for pki_issuer_sign_intermediate

        """
        pass

    def test_pki_issuer_sign_revocation_list(self) -> None:
        """Test case for pki_issuer_sign_revocation_list

        """
        pass

    def test_pki_issuer_sign_self_issued(self) -> None:
        """Test case for pki_issuer_sign_self_issued

        """
        pass

    def test_pki_issuer_sign_verbatim(self) -> None:
        """Test case for pki_issuer_sign_verbatim

        """
        pass

    def test_pki_issuer_sign_verbatim_with_role(self) -> None:
        """Test case for pki_issuer_sign_verbatim_with_role

        """
        pass

    def test_pki_issuer_sign_with_role(self) -> None:
        """Test case for pki_issuer_sign_with_role

        """
        pass

    def test_pki_issuers_generate_intermediate(self) -> None:
        """Test case for pki_issuers_generate_intermediate

        """
        pass

    def test_pki_issuers_generate_root(self) -> None:
        """Test case for pki_issuers_generate_root

        """
        pass

    def test_pki_issuers_import_bundle(self) -> None:
        """Test case for pki_issuers_import_bundle

        """
        pass

    def test_pki_issuers_import_cert(self) -> None:
        """Test case for pki_issuers_import_cert

        """
        pass

    def test_pki_list_certs(self) -> None:
        """Test case for pki_list_certs

        """
        pass

    def test_pki_list_eab_keys(self) -> None:
        """Test case for pki_list_eab_keys

        """
        pass

    def test_pki_list_issuers(self) -> None:
        """Test case for pki_list_issuers

        """
        pass

    def test_pki_list_keys(self) -> None:
        """Test case for pki_list_keys

        """
        pass

    def test_pki_list_revoked_certs(self) -> None:
        """Test case for pki_list_revoked_certs

        """
        pass

    def test_pki_list_roles(self) -> None:
        """Test case for pki_list_roles

        """
        pass

    def test_pki_query_ocsp(self) -> None:
        """Test case for pki_query_ocsp

        """
        pass

    def test_pki_query_ocsp_with_get_req(self) -> None:
        """Test case for pki_query_ocsp_with_get_req

        """
        pass

    def test_pki_read_acme_configuration(self) -> None:
        """Test case for pki_read_acme_configuration

        """
        pass

    def test_pki_read_acme_directory(self) -> None:
        """Test case for pki_read_acme_directory

        """
        pass

    def test_pki_read_acme_new_nonce(self) -> None:
        """Test case for pki_read_acme_new_nonce

        """
        pass

    def test_pki_read_auto_tidy_configuration(self) -> None:
        """Test case for pki_read_auto_tidy_configuration

        """
        pass

    def test_pki_read_ca_chain_pem(self) -> None:
        """Test case for pki_read_ca_chain_pem

        """
        pass

    def test_pki_read_ca_der(self) -> None:
        """Test case for pki_read_ca_der

        """
        pass

    def test_pki_read_ca_pem(self) -> None:
        """Test case for pki_read_ca_pem

        """
        pass

    def test_pki_read_cert(self) -> None:
        """Test case for pki_read_cert

        """
        pass

    def test_pki_read_cert_ca_chain(self) -> None:
        """Test case for pki_read_cert_ca_chain

        """
        pass

    def test_pki_read_cert_crl(self) -> None:
        """Test case for pki_read_cert_crl

        """
        pass

    def test_pki_read_cert_delta_crl(self) -> None:
        """Test case for pki_read_cert_delta_crl

        """
        pass

    def test_pki_read_cert_raw_der(self) -> None:
        """Test case for pki_read_cert_raw_der

        """
        pass

    def test_pki_read_cert_raw_pem(self) -> None:
        """Test case for pki_read_cert_raw_pem

        """
        pass

    def test_pki_read_cluster_configuration(self) -> None:
        """Test case for pki_read_cluster_configuration

        """
        pass

    def test_pki_read_crl_configuration(self) -> None:
        """Test case for pki_read_crl_configuration

        """
        pass

    def test_pki_read_crl_delta(self) -> None:
        """Test case for pki_read_crl_delta

        """
        pass

    def test_pki_read_crl_delta_pem(self) -> None:
        """Test case for pki_read_crl_delta_pem

        """
        pass

    def test_pki_read_crl_der(self) -> None:
        """Test case for pki_read_crl_der

        """
        pass

    def test_pki_read_crl_pem(self) -> None:
        """Test case for pki_read_crl_pem

        """
        pass

    def test_pki_read_issuer(self) -> None:
        """Test case for pki_read_issuer

        """
        pass

    def test_pki_read_issuer_der(self) -> None:
        """Test case for pki_read_issuer_der

        """
        pass

    def test_pki_read_issuer_issuer_ref_acme_directory(self) -> None:
        """Test case for pki_read_issuer_issuer_ref_acme_directory

        """
        pass

    def test_pki_read_issuer_issuer_ref_acme_new_nonce(self) -> None:
        """Test case for pki_read_issuer_issuer_ref_acme_new_nonce

        """
        pass

    def test_pki_read_issuer_issuer_ref_roles_role_acme_directory(self) -> None:
        """Test case for pki_read_issuer_issuer_ref_roles_role_acme_directory

        """
        pass

    def test_pki_read_issuer_issuer_ref_roles_role_acme_new_nonce(self) -> None:
        """Test case for pki_read_issuer_issuer_ref_roles_role_acme_new_nonce

        """
        pass

    def test_pki_read_issuer_json(self) -> None:
        """Test case for pki_read_issuer_json

        """
        pass

    def test_pki_read_issuer_pem(self) -> None:
        """Test case for pki_read_issuer_pem

        """
        pass

    def test_pki_read_issuers_configuration(self) -> None:
        """Test case for pki_read_issuers_configuration

        """
        pass

    def test_pki_read_key(self) -> None:
        """Test case for pki_read_key

        """
        pass

    def test_pki_read_keys_configuration(self) -> None:
        """Test case for pki_read_keys_configuration

        """
        pass

    def test_pki_read_role(self) -> None:
        """Test case for pki_read_role

        """
        pass

    def test_pki_read_roles_role_acme_directory(self) -> None:
        """Test case for pki_read_roles_role_acme_directory

        """
        pass

    def test_pki_read_roles_role_acme_new_nonce(self) -> None:
        """Test case for pki_read_roles_role_acme_new_nonce

        """
        pass

    def test_pki_read_urls_configuration(self) -> None:
        """Test case for pki_read_urls_configuration

        """
        pass

    def test_pki_replace_root(self) -> None:
        """Test case for pki_replace_root

        """
        pass

    def test_pki_revoke(self) -> None:
        """Test case for pki_revoke

        """
        pass

    def test_pki_revoke_issuer(self) -> None:
        """Test case for pki_revoke_issuer

        """
        pass

    def test_pki_revoke_with_key(self) -> None:
        """Test case for pki_revoke_with_key

        """
        pass

    def test_pki_root_sign_intermediate(self) -> None:
        """Test case for pki_root_sign_intermediate

        """
        pass

    def test_pki_root_sign_self_issued(self) -> None:
        """Test case for pki_root_sign_self_issued

        """
        pass

    def test_pki_rotate_crl(self) -> None:
        """Test case for pki_rotate_crl

        """
        pass

    def test_pki_rotate_delta_crl(self) -> None:
        """Test case for pki_rotate_delta_crl

        """
        pass

    def test_pki_rotate_root(self) -> None:
        """Test case for pki_rotate_root

        """
        pass

    def test_pki_set_signed_intermediate(self) -> None:
        """Test case for pki_set_signed_intermediate

        """
        pass

    def test_pki_sign_verbatim(self) -> None:
        """Test case for pki_sign_verbatim

        """
        pass

    def test_pki_sign_verbatim_with_role(self) -> None:
        """Test case for pki_sign_verbatim_with_role

        """
        pass

    def test_pki_sign_with_role(self) -> None:
        """Test case for pki_sign_with_role

        """
        pass

    def test_pki_tidy(self) -> None:
        """Test case for pki_tidy

        """
        pass

    def test_pki_tidy_cancel(self) -> None:
        """Test case for pki_tidy_cancel

        """
        pass

    def test_pki_tidy_status(self) -> None:
        """Test case for pki_tidy_status

        """
        pass

    def test_pki_write_acme_account_kid(self) -> None:
        """Test case for pki_write_acme_account_kid

        """
        pass

    def test_pki_write_acme_authorization_auth_id(self) -> None:
        """Test case for pki_write_acme_authorization_auth_id

        """
        pass

    def test_pki_write_acme_challenge_auth_id_challenge_type(self) -> None:
        """Test case for pki_write_acme_challenge_auth_id_challenge_type

        """
        pass

    def test_pki_write_acme_new_account(self) -> None:
        """Test case for pki_write_acme_new_account

        """
        pass

    def test_pki_write_acme_new_order(self) -> None:
        """Test case for pki_write_acme_new_order

        """
        pass

    def test_pki_write_acme_order_order_id(self) -> None:
        """Test case for pki_write_acme_order_order_id

        """
        pass

    def test_pki_write_acme_order_order_id_cert(self) -> None:
        """Test case for pki_write_acme_order_order_id_cert

        """
        pass

    def test_pki_write_acme_order_order_id_finalize(self) -> None:
        """Test case for pki_write_acme_order_order_id_finalize

        """
        pass

    def test_pki_write_acme_orders(self) -> None:
        """Test case for pki_write_acme_orders

        """
        pass

    def test_pki_write_acme_revoke_cert(self) -> None:
        """Test case for pki_write_acme_revoke_cert

        """
        pass

    def test_pki_write_issuer(self) -> None:
        """Test case for pki_write_issuer

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_account_kid(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_account_kid

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_authorization_auth_id(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_authorization_auth_id

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_new_account(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_new_account

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_new_order(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_new_order

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_order_order_id(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_order_order_id

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_order_order_id_cert(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_order_order_id_cert

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_order_order_id_finalize(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_order_order_id_finalize

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_orders(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_orders

        """
        pass

    def test_pki_write_issuer_issuer_ref_acme_revoke_cert(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_acme_revoke_cert

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_account_kid(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_account_kid

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_new_account(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_new_account

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_new_order(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_new_order

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_order_order_id(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_order_order_id

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_orders(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_orders

        """
        pass

    def test_pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert(self) -> None:
        """Test case for pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert

        """
        pass

    def test_pki_write_key(self) -> None:
        """Test case for pki_write_key

        """
        pass

    def test_pki_write_role(self) -> None:
        """Test case for pki_write_role

        """
        pass

    def test_pki_write_roles_role_acme_account_kid(self) -> None:
        """Test case for pki_write_roles_role_acme_account_kid

        """
        pass

    def test_pki_write_roles_role_acme_authorization_auth_id(self) -> None:
        """Test case for pki_write_roles_role_acme_authorization_auth_id

        """
        pass

    def test_pki_write_roles_role_acme_challenge_auth_id_challenge_type(self) -> None:
        """Test case for pki_write_roles_role_acme_challenge_auth_id_challenge_type

        """
        pass

    def test_pki_write_roles_role_acme_new_account(self) -> None:
        """Test case for pki_write_roles_role_acme_new_account

        """
        pass

    def test_pki_write_roles_role_acme_new_order(self) -> None:
        """Test case for pki_write_roles_role_acme_new_order

        """
        pass

    def test_pki_write_roles_role_acme_order_order_id(self) -> None:
        """Test case for pki_write_roles_role_acme_order_order_id

        """
        pass

    def test_pki_write_roles_role_acme_order_order_id_cert(self) -> None:
        """Test case for pki_write_roles_role_acme_order_order_id_cert

        """
        pass

    def test_pki_write_roles_role_acme_order_order_id_finalize(self) -> None:
        """Test case for pki_write_roles_role_acme_order_order_id_finalize

        """
        pass

    def test_pki_write_roles_role_acme_orders(self) -> None:
        """Test case for pki_write_roles_role_acme_orders

        """
        pass

    def test_pki_write_roles_role_acme_revoke_cert(self) -> None:
        """Test case for pki_write_roles_role_acme_revoke_cert

        """
        pass

    def test_rabbit_mq_configure_connection(self) -> None:
        """Test case for rabbit_mq_configure_connection

        Configure the connection URI, username, and password to talk to RabbitMQ management HTTP API.
        """
        pass

    def test_rabbit_mq_configure_lease(self) -> None:
        """Test case for rabbit_mq_configure_lease

        """
        pass

    def test_rabbit_mq_delete_role(self) -> None:
        """Test case for rabbit_mq_delete_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_rabbit_mq_list_roles(self) -> None:
        """Test case for rabbit_mq_list_roles

        Manage the roles that can be created with this backend.
        """
        pass

    def test_rabbit_mq_read_lease_configuration(self) -> None:
        """Test case for rabbit_mq_read_lease_configuration

        """
        pass

    def test_rabbit_mq_read_role(self) -> None:
        """Test case for rabbit_mq_read_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_rabbit_mq_request_credentials(self) -> None:
        """Test case for rabbit_mq_request_credentials

        Request RabbitMQ credentials for a certain role.
        """
        pass

    def test_rabbit_mq_write_role(self) -> None:
        """Test case for rabbit_mq_write_role

        Manage the roles that can be created with this backend.
        """
        pass

    def test_ssh_configure_ca(self) -> None:
        """Test case for ssh_configure_ca

        """
        pass

    def test_ssh_configure_zero_address(self) -> None:
        """Test case for ssh_configure_zero_address

        """
        pass

    def test_ssh_delete_ca_configuration(self) -> None:
        """Test case for ssh_delete_ca_configuration

        """
        pass

    def test_ssh_delete_role(self) -> None:
        """Test case for ssh_delete_role

        Manage the 'roles' that can be created with this backend.
        """
        pass

    def test_ssh_delete_zero_address_configuration(self) -> None:
        """Test case for ssh_delete_zero_address_configuration

        """
        pass

    def test_ssh_generate_credentials(self) -> None:
        """Test case for ssh_generate_credentials

        Creates a credential for establishing SSH connection with the remote host.
        """
        pass

    def test_ssh_issue_certificate(self) -> None:
        """Test case for ssh_issue_certificate

        """
        pass

    def test_ssh_list_roles(self) -> None:
        """Test case for ssh_list_roles

        Manage the 'roles' that can be created with this backend.
        """
        pass

    def test_ssh_list_roles_by_ip(self) -> None:
        """Test case for ssh_list_roles_by_ip

        List all the roles associated with the given IP address.
        """
        pass

    def test_ssh_read_ca_configuration(self) -> None:
        """Test case for ssh_read_ca_configuration

        """
        pass

    def test_ssh_read_public_key(self) -> None:
        """Test case for ssh_read_public_key

        Retrieve the public key.
        """
        pass

    def test_ssh_read_role(self) -> None:
        """Test case for ssh_read_role

        Manage the 'roles' that can be created with this backend.
        """
        pass

    def test_ssh_read_zero_address_configuration(self) -> None:
        """Test case for ssh_read_zero_address_configuration

        """
        pass

    def test_ssh_sign_certificate(self) -> None:
        """Test case for ssh_sign_certificate

        Request signing an SSH key using a certain role with the provided details.
        """
        pass

    def test_ssh_tidy_dynamic_host_keys(self) -> None:
        """Test case for ssh_tidy_dynamic_host_keys

        This endpoint removes the stored host keys used for the removed Dynamic Key feature, if present.
        """
        pass

    def test_ssh_verify_otp(self) -> None:
        """Test case for ssh_verify_otp

        Validate the OTP provided by Vault SSH Agent.
        """
        pass

    def test_ssh_write_role(self) -> None:
        """Test case for ssh_write_role

        Manage the 'roles' that can be created with this backend.
        """
        pass

    def test_terraform_cloud_configure(self) -> None:
        """Test case for terraform_cloud_configure

        """
        pass

    def test_terraform_cloud_delete_configuration(self) -> None:
        """Test case for terraform_cloud_delete_configuration

        """
        pass

    def test_terraform_cloud_delete_role(self) -> None:
        """Test case for terraform_cloud_delete_role

        """
        pass

    def test_terraform_cloud_generate_credentials(self) -> None:
        """Test case for terraform_cloud_generate_credentials

        """
        pass

    def test_terraform_cloud_generate_credentials2(self) -> None:
        """Test case for terraform_cloud_generate_credentials2

        """
        pass

    def test_terraform_cloud_list_roles(self) -> None:
        """Test case for terraform_cloud_list_roles

        """
        pass

    def test_terraform_cloud_read_configuration(self) -> None:
        """Test case for terraform_cloud_read_configuration

        """
        pass

    def test_terraform_cloud_read_role(self) -> None:
        """Test case for terraform_cloud_read_role

        """
        pass

    def test_terraform_cloud_rotate_role(self) -> None:
        """Test case for terraform_cloud_rotate_role

        """
        pass

    def test_terraform_cloud_write_role(self) -> None:
        """Test case for terraform_cloud_write_role

        """
        pass

    def test_totp_create_key(self) -> None:
        """Test case for totp_create_key

        """
        pass

    def test_totp_delete_key(self) -> None:
        """Test case for totp_delete_key

        """
        pass

    def test_totp_generate_code(self) -> None:
        """Test case for totp_generate_code

        """
        pass

    def test_totp_list_keys(self) -> None:
        """Test case for totp_list_keys

        Manage the keys that can be created with this backend.
        """
        pass

    def test_totp_read_key(self) -> None:
        """Test case for totp_read_key

        """
        pass

    def test_totp_validate_code(self) -> None:
        """Test case for totp_validate_code

        """
        pass

    def test_transit_back_up_key(self) -> None:
        """Test case for transit_back_up_key

        Backup the named key
        """
        pass

    def test_transit_byok_key(self) -> None:
        """Test case for transit_byok_key

        Securely export named encryption or signing key
        """
        pass

    def test_transit_byok_key_version(self) -> None:
        """Test case for transit_byok_key_version

        Securely export named encryption or signing key
        """
        pass

    def test_transit_configure_cache(self) -> None:
        """Test case for transit_configure_cache

        Configures a new cache of the specified size
        """
        pass

    def test_transit_configure_key(self) -> None:
        """Test case for transit_configure_key

        Configure a named encryption key
        """
        pass

    def test_transit_configure_keys(self) -> None:
        """Test case for transit_configure_keys

        """
        pass

    def test_transit_create_key(self) -> None:
        """Test case for transit_create_key

        """
        pass

    def test_transit_decrypt(self) -> None:
        """Test case for transit_decrypt

        Decrypt a ciphertext value using a named key
        """
        pass

    def test_transit_delete_key(self) -> None:
        """Test case for transit_delete_key

        """
        pass

    def test_transit_encrypt(self) -> None:
        """Test case for transit_encrypt

        Encrypt a plaintext value or a batch of plaintext blocks using a named key
        """
        pass

    def test_transit_export_key(self) -> None:
        """Test case for transit_export_key

        Export named encryption or signing key
        """
        pass

    def test_transit_export_key_version(self) -> None:
        """Test case for transit_export_key_version

        Export named encryption or signing key
        """
        pass

    def test_transit_generate_csr_for_key(self) -> None:
        """Test case for transit_generate_csr_for_key

        """
        pass

    def test_transit_generate_data_key(self) -> None:
        """Test case for transit_generate_data_key

        Generate a data key
        """
        pass

    def test_transit_generate_hmac(self) -> None:
        """Test case for transit_generate_hmac

        Generate an HMAC for input data using the named key
        """
        pass

    def test_transit_generate_hmac_with_algorithm(self) -> None:
        """Test case for transit_generate_hmac_with_algorithm

        Generate an HMAC for input data using the named key
        """
        pass

    def test_transit_generate_random(self) -> None:
        """Test case for transit_generate_random

        Generate random bytes
        """
        pass

    def test_transit_generate_random_with_bytes(self) -> None:
        """Test case for transit_generate_random_with_bytes

        Generate random bytes
        """
        pass

    def test_transit_generate_random_with_source(self) -> None:
        """Test case for transit_generate_random_with_source

        Generate random bytes
        """
        pass

    def test_transit_generate_random_with_source_and_bytes(self) -> None:
        """Test case for transit_generate_random_with_source_and_bytes

        Generate random bytes
        """
        pass

    def test_transit_hash(self) -> None:
        """Test case for transit_hash

        Generate a hash sum for input data
        """
        pass

    def test_transit_hash_with_algorithm(self) -> None:
        """Test case for transit_hash_with_algorithm

        Generate a hash sum for input data
        """
        pass

    def test_transit_import_key(self) -> None:
        """Test case for transit_import_key

        Imports an externally-generated key into a new transit key
        """
        pass

    def test_transit_import_key_version(self) -> None:
        """Test case for transit_import_key_version

        Imports an externally-generated key into an existing imported key
        """
        pass

    def test_transit_list_keys(self) -> None:
        """Test case for transit_list_keys

        Managed named encryption keys
        """
        pass

    def test_transit_read_cache_configuration(self) -> None:
        """Test case for transit_read_cache_configuration

        Returns the size of the active cache
        """
        pass

    def test_transit_read_key(self) -> None:
        """Test case for transit_read_key

        """
        pass

    def test_transit_read_keys_configuration(self) -> None:
        """Test case for transit_read_keys_configuration

        """
        pass

    def test_transit_read_wrapping_key(self) -> None:
        """Test case for transit_read_wrapping_key

        Returns the public key to use for wrapping imported keys
        """
        pass

    def test_transit_restore_and_rename_key(self) -> None:
        """Test case for transit_restore_and_rename_key

        Restore the named key
        """
        pass

    def test_transit_restore_key(self) -> None:
        """Test case for transit_restore_key

        Restore the named key
        """
        pass

    def test_transit_rewrap(self) -> None:
        """Test case for transit_rewrap

        Rewrap ciphertext
        """
        pass

    def test_transit_rotate_key(self) -> None:
        """Test case for transit_rotate_key

        Rotate named encryption key
        """
        pass

    def test_transit_set_certificate_for_key(self) -> None:
        """Test case for transit_set_certificate_for_key

        """
        pass

    def test_transit_sign(self) -> None:
        """Test case for transit_sign

        Generate a signature for input data using the named key
        """
        pass

    def test_transit_sign_with_algorithm(self) -> None:
        """Test case for transit_sign_with_algorithm

        Generate a signature for input data using the named key
        """
        pass

    def test_transit_trim_key(self) -> None:
        """Test case for transit_trim_key

        Trim key versions of a named key
        """
        pass

    def test_transit_verify(self) -> None:
        """Test case for transit_verify

        Verify a signature or HMAC for input data created using the named key
        """
        pass

    def test_transit_verify_with_algorithm(self) -> None:
        """Test case for transit_verify_with_algorithm

        Verify a signature or HMAC for input data created using the named key
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsConfigureClientRequest(BaseModel):
    """
    AwsConfigureClientRequest
    """ # noqa: E501
    access_key: Optional[StrictStr] = Field(default='', description="AWS Access Key ID for the account used to make AWS API requests.")
    allowed_sts_header_values: Optional[List[StrictStr]] = Field(default=None, description="List of additional headers that are allowed to be in AWS STS request headers")
    endpoint: Optional[StrictStr] = Field(default='', description="URL to override the default generated endpoint for making AWS EC2 API calls.")
    iam_endpoint: Optional[StrictStr] = Field(default='', description="URL to override the default generated endpoint for making AWS IAM API calls.")
    iam_server_id_header_value: Optional[StrictStr] = Field(default='', description="Value to require in the X-Vault-AWS-IAM-Server-ID request header")
    max_retries: Optional[StrictInt] = Field(default=-1, description="Maximum number of retries for recoverable exceptions of AWS APIs")
    secret_key: Optional[StrictStr] = Field(default='', description="AWS Secret Access Key for the account used to make AWS API requests.")
    sts_endpoint: Optional[StrictStr] = Field(default='', description="URL to override the default generated endpoint for making AWS STS API calls.")
    sts_region: Optional[StrictStr] = Field(default='', description="The region ID for the sts_endpoint, if set.")
    use_sts_region_from_client: Optional[StrictBool] = Field(default=False, description="Uses the STS region from client requests for making AWS STS API calls.")
    __properties: ClassVar[List[str]] = ["access_key", "allowed_sts_header_values", "endpoint", "iam_endpoint", "iam_server_id_header_value", "max_retries", "secret_key", "sts_endpoint", "sts_region", "use_sts_region_from_client"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsConfigureClientRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsConfigureClientRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "access_key": obj.get("access_key") if obj.get("access_key") is not None else '',
            "allowed_sts_header_values": obj.get("allowed_sts_header_values"),
            "endpoint": obj.get("endpoint") if obj.get("endpoint") is not None else '',
            "iam_endpoint": obj.get("iam_endpoint") if obj.get("iam_endpoint") is not None else '',
            "iam_server_id_header_value": obj.get("iam_server_id_header_value") if obj.get("iam_server_id_header_value") is not None else '',
            "max_retries": obj.get("max_retries") if obj.get("max_retries") is not None else -1,
            "secret_key": obj.get("secret_key") if obj.get("secret_key") is not None else '',
            "sts_endpoint": obj.get("sts_endpoint") if obj.get("sts_endpoint") is not None else '',
            "sts_region": obj.get("sts_region") if obj.get("sts_region") is not None else '',
            "use_sts_region_from_client": obj.get("use_sts_region_from_client") if obj.get("use_sts_region_from_client") is not None else False
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TransitCreateKeyRequest(BaseModel):
    """
    TransitCreateKeyRequest
    """ # noqa: E501
    allow_plaintext_backup: Optional[StrictBool] = Field(default=None, description="Enables taking a backup of the named key in plaintext format. Once set, this cannot be disabled.")
    auto_rotate_period: Optional[StrictStr] = Field(default='0', description="Amount of time the key should live before being automatically rotated. A value of 0 (default) disables automatic rotation for the key.")
    context: Optional[StrictStr] = Field(default=None, description="Base64 encoded context for key derivation. When reading a key with key derivation enabled, if the key type supports public keys, this will return the public key for the given context.")
    convergent_encryption: Optional[StrictBool] = Field(default=None, description="Whether to support convergent encryption. This is only supported when using a key with key derivation enabled and will require all requests to carry both a context and 96-bit (12-byte) nonce. The given nonce will be used in place of a randomly generated nonce. As a result, when the same context and nonce are supplied, the same ciphertext is generated. It is *very important* when using this mode that you ensure that all nonces are unique for a given context. Failing to do so will severely impact the ciphertext's security.")
    derived: Optional[StrictBool] = Field(default=None, description="Enables key derivation mode. This allows for per-transaction unique keys for encryption operations.")
    exportable: Optional[StrictBool] = Field(default=None, description="Enables keys to be exportable. This allows for all the valid keys in the key ring to be exported.")
    key_size: Optional[StrictInt] = Field(default=0, description="The key size in bytes for the algorithm. Only applies to HMAC and must be no fewer than 32 bytes and no more than 512")
    managed_key_id: Optional[StrictStr] = Field(default=None, description="The UUID of the managed key to use for this transit key")
    managed_key_name: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use for this transit key")
    type: Optional[StrictStr] = Field(default='aes256-gcm96', description="The type of key to create. Currently, \"aes128-gcm96\" (symmetric), \"aes256-gcm96\" (symmetric), \"ecdsa-p256\" (asymmetric), \"ecdsa-p384\" (asymmetric), \"ecdsa-p521\" (asymmetric), \"ed25519\" (asymmetric), \"rsa-2048\" (asymmetric), \"rsa-3072\" (asymmetric), \"rsa-4096\" (asymmetric) are supported. Defaults to \"aes256-gcm96\".")
    __properties: ClassVar[List[str]] = ["allow_plaintext_backup", "auto_rotate_period", "context", "convergent_encryption", "derived", "exportable", "key_size", "managed_key_id", "managed_key_name", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransitCreateKeyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransitCreateKeyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_plaintext_backup": obj.get("allow_plaintext_backup"),
            "auto_rotate_period": obj.get("auto_rotate_period") if obj.get("auto_rotate_period") is not None else '0',
            "context": obj.get("context"),
            "convergent_encryption": obj.get("convergent_encryption"),
            "derived": obj.get("derived"),
            "exportable": obj.get("exportable"),
            "key_size": obj.get("key_size") if obj.get("key_size") is not None else 0,
            "managed_key_id": obj.get("managed_key_id"),
            "managed_key_name": obj.get("managed_key_name"),
            "type": obj.get("type") if obj.get("type") is not None else 'aes256-gcm96'
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class UnsealResponse(BaseModel):
    """
    UnsealResponse
    """ # noqa: E501
    build_date: Optional[StrictStr] = None
    cluster_id: Optional[StrictStr] = None
    cluster_name: Optional[StrictStr] = None
    hcp_link_resource_id: Optional[StrictStr] = Field(default=None, alias="hcp_link_resource_ID")
    hcp_link_status: Optional[StrictStr] = None
    initialized: Optional[StrictBool] = None
    migration: Optional[StrictBool] = None
    n: Optional[StrictInt] = None
    nonce: Optional[StrictStr] = None
    progress: Optional[StrictInt] = None
    recovery_seal: Optional[StrictBool] = None
    sealed: Optional[StrictBool] = None
    storage_type: Optional[StrictStr] = None
    t: Optional[StrictInt] = None
    type: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["build_date", "cluster_id", "cluster_name", "hcp_link_resource_ID", "hcp_link_status", "initialized", "migration", "n", "nonce", "progress", "recovery_seal", "sealed", "storage_type", "t", "type", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnsealResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnsealResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "build_date": obj.get("build_date"),
            "cluster_id": obj.get("cluster_id"),
            "cluster_name": obj.get("cluster_name"),
            "hcp_link_resource_ID": obj.get("hcp_link_resource_ID"),
            "hcp_link_status": obj.get("hcp_link_status"),
            "initialized": obj.get("initialized"),
            "migration": obj.get("migration"),
            "n": obj.get("n"),
            "nonce": obj.get("nonce"),
            "progress": obj.get("progress"),
            "recovery_seal": obj.get("recovery_seal"),
            "sealed": obj.get("sealed"),
            "storage_type": obj.get("storage_type"),
            "t": obj.get("t"),
            "type": obj.get("type"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TransitEncryptRequest(BaseModel):
    """
    TransitEncryptRequest
    """ # noqa: E501
    associated_data: Optional[StrictStr] = Field(default=None, description="When using an AEAD cipher mode, such as AES-GCM, this parameter allows passing associated data (AD/AAD) into the encryption function; this data must be passed on subsequent decryption requests but can be transited in plaintext. On successful decryption, both the ciphertext and the associated data are attested not to have been tampered with.")
    batch_input: Optional[List[Dict[str, Any]]] = Field(default=None, description="Specifies a list of items to be encrypted in a single batch. When this parameter is set, if the parameters 'plaintext', 'context' and 'nonce' are also set, they will be ignored. Any batch output will preserve the order of the batch input.")
    context: Optional[StrictStr] = Field(default=None, description="Base64 encoded context for key derivation. Required if key derivation is enabled")
    convergent_encryption: Optional[StrictBool] = Field(default=None, description="This parameter will only be used when a key is expected to be created. Whether to support convergent encryption. This is only supported when using a key with key derivation enabled and will require all requests to carry both a context and 96-bit (12-byte) nonce. The given nonce will be used in place of a randomly generated nonce. As a result, when the same context and nonce are supplied, the same ciphertext is generated. It is *very important* when using this mode that you ensure that all nonces are unique for a given context. Failing to do so will severely impact the ciphertext's security.")
    key_version: Optional[StrictInt] = Field(default=None, description="The version of the key to use for encryption. Must be 0 (for latest) or a value greater than or equal to the min_encryption_version configured on the key.")
    nonce: Optional[StrictStr] = Field(default=None, description="Base64 encoded nonce value. Must be provided if convergent encryption is enabled for this key and the key was generated with Vault 0.6.1. Not required for keys created in 0.6.2+. The value must be exactly 96 bits (12 bytes) long and the user must ensure that for any given context (and thus, any given encryption key) this nonce value is **never reused**.")
    partial_failure_response_code: Optional[StrictInt] = Field(default=None, description="Ordinarily, if a batch item fails to encrypt due to a bad input, but other batch items succeed, the HTTP response code is 400 (Bad Request). Some applications may want to treat partial failures differently. Providing the parameter returns the given response code integer instead of a 400 in this case. If all values fail HTTP 400 is still returned.")
    plaintext: Optional[StrictStr] = Field(default=None, description="Base64 encoded plaintext value to be encrypted")
    type: Optional[StrictStr] = Field(default='aes256-gcm96', description="This parameter is required when encryption key is expected to be created. When performing an upsert operation, the type of key to create. Currently, \"aes128-gcm96\" (symmetric) and \"aes256-gcm96\" (symmetric) are the only types supported. Defaults to \"aes256-gcm96\".")
    __properties: ClassVar[List[str]] = ["associated_data", "batch_input", "context", "convergent_encryption", "key_version", "nonce", "partial_failure_response_code", "plaintext", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransitEncryptRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransitEncryptRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "associated_data": obj.get("associated_data"),
            "batch_input": obj.get("batch_input"),
            "context": obj.get("context"),
            "convergent_encryption": obj.get("convergent_encryption"),
            "key_version": obj.get("key_version"),
            "nonce": obj.get("nonce"),
            "partial_failure_response_code": obj.get("partial_failure_response_code"),
            "plaintext": obj.get("plaintext"),
            "type": obj.get("type") if obj.get("type") is not None else 'aes256-gcm96'
        })
        return _obj


